from enum import Enum


class PostgresqlSslMode(str, Enum):
    ALLOW = "allow"
    DISABLE = "disable"
    PREFER = "prefer"
    REQUIRE = "require"
    VERIFY_CA = "verify-ca"
    VERIFY_FULL = "verify-full"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class SingleStoreDbLoadBalancingMode(str, Enum):
    LOADBALANCE = "loadbalance"
    NONE = "none"
    SEQUENTIAL = "sequential"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="LabelModel")


@_attrs_define
class LabelModel:
    """Label model that is returned by the REST API. A label is a tag that was assigned to a data source, table, column or
    a single check. Labels play the role of a business glossary.

        Attributes:
            label (Union[Unset, str]): Label text.
            labels_count (Union[Unset, int]): The number of data assets tagged with this label.
            nested_labels_count (Union[Unset, int]): The number of data assets tagged with nested labels below this prefix
                node. For example, if the current label is "address", and there are nested labels "address/city" and
                "address/zipcode", this value returns the count of data assets tagged with these nested tags.
    """

    label: Union[Unset, str] = UNSET
    labels_count: Union[Unset, int] = UNSET
    nested_labels_count: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        label = self.label
        labels_count = self.labels_count
        nested_labels_count = self.nested_labels_count

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if label is not UNSET:
            field_dict["label"] = label
        if labels_count is not UNSET:
            field_dict["labels_count"] = labels_count
        if nested_labels_count is not UNSET:
            field_dict["nested_labels_count"] = nested_labels_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        label = d.pop("label", UNSET)

        labels_count = d.pop("labels_count", UNSET)

        nested_labels_count = d.pop("nested_labels_count", UNSET)

        label_model = cls(
            label=label,
            labels_count=labels_count,
            nested_labels_count=nested_labels_count,
        )

        label_model.additional_properties = d
        return label_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_whitespace_empty_text_found_check_spec import (
        ColumnWhitespaceEmptyTextFoundCheckSpec,
    )
    from ..models.column_whitespace_empty_text_percent_check_spec import (
        ColumnWhitespaceEmptyTextPercentCheckSpec,
    )
    from ..models.column_whitespace_monthly_partitioned_checks_spec_custom_checks import (
        ColumnWhitespaceMonthlyPartitionedChecksSpecCustomChecks,
    )
    from ..models.column_whitespace_null_placeholder_text_found_check_spec import (
        ColumnWhitespaceNullPlaceholderTextFoundCheckSpec,
    )
    from ..models.column_whitespace_null_placeholder_text_percent_check_spec import (
        ColumnWhitespaceNullPlaceholderTextPercentCheckSpec,
    )
    from ..models.column_whitespace_text_surrounded_by_whitespace_found_check_spec import (
        ColumnWhitespaceTextSurroundedByWhitespaceFoundCheckSpec,
    )
    from ..models.column_whitespace_text_surrounded_by_whitespace_percent_check_spec import (
        ColumnWhitespaceTextSurroundedByWhitespacePercentCheckSpec,
    )
    from ..models.column_whitespace_whitespace_text_found_check_spec import (
        ColumnWhitespaceWhitespaceTextFoundCheckSpec,
    )
    from ..models.column_whitespace_whitespace_text_percent_check_spec import (
        ColumnWhitespaceWhitespaceTextPercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnWhitespaceMonthlyPartitionedChecksSpec")


@_attrs_define
class ColumnWhitespaceMonthlyPartitionedChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnWhitespaceMonthlyPartitionedChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        monthly_partition_empty_text_found (Union[Unset, ColumnWhitespaceEmptyTextFoundCheckSpec]):
        monthly_partition_whitespace_text_found (Union[Unset, ColumnWhitespaceWhitespaceTextFoundCheckSpec]):
        monthly_partition_null_placeholder_text_found (Union[Unset, ColumnWhitespaceNullPlaceholderTextFoundCheckSpec]):
        monthly_partition_empty_text_percent (Union[Unset, ColumnWhitespaceEmptyTextPercentCheckSpec]):
        monthly_partition_whitespace_text_percent (Union[Unset, ColumnWhitespaceWhitespaceTextPercentCheckSpec]):
        monthly_partition_null_placeholder_text_percent (Union[Unset,
            ColumnWhitespaceNullPlaceholderTextPercentCheckSpec]):
        monthly_partition_text_surrounded_by_whitespace_found (Union[Unset,
            ColumnWhitespaceTextSurroundedByWhitespaceFoundCheckSpec]):
        monthly_partition_text_surrounded_by_whitespace_percent (Union[Unset,
            ColumnWhitespaceTextSurroundedByWhitespacePercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnWhitespaceMonthlyPartitionedChecksSpecCustomChecks"
    ] = UNSET
    monthly_partition_empty_text_found: Union[
        Unset, "ColumnWhitespaceEmptyTextFoundCheckSpec"
    ] = UNSET
    monthly_partition_whitespace_text_found: Union[
        Unset, "ColumnWhitespaceWhitespaceTextFoundCheckSpec"
    ] = UNSET
    monthly_partition_null_placeholder_text_found: Union[
        Unset, "ColumnWhitespaceNullPlaceholderTextFoundCheckSpec"
    ] = UNSET
    monthly_partition_empty_text_percent: Union[
        Unset, "ColumnWhitespaceEmptyTextPercentCheckSpec"
    ] = UNSET
    monthly_partition_whitespace_text_percent: Union[
        Unset, "ColumnWhitespaceWhitespaceTextPercentCheckSpec"
    ] = UNSET
    monthly_partition_null_placeholder_text_percent: Union[
        Unset, "ColumnWhitespaceNullPlaceholderTextPercentCheckSpec"
    ] = UNSET
    monthly_partition_text_surrounded_by_whitespace_found: Union[
        Unset, "ColumnWhitespaceTextSurroundedByWhitespaceFoundCheckSpec"
    ] = UNSET
    monthly_partition_text_surrounded_by_whitespace_percent: Union[
        Unset, "ColumnWhitespaceTextSurroundedByWhitespacePercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_partition_empty_text_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_empty_text_found, Unset):
            monthly_partition_empty_text_found = (
                self.monthly_partition_empty_text_found.to_dict()
            )

        monthly_partition_whitespace_text_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_whitespace_text_found, Unset):
            monthly_partition_whitespace_text_found = (
                self.monthly_partition_whitespace_text_found.to_dict()
            )

        monthly_partition_null_placeholder_text_found: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.monthly_partition_null_placeholder_text_found, Unset):
            monthly_partition_null_placeholder_text_found = (
                self.monthly_partition_null_placeholder_text_found.to_dict()
            )

        monthly_partition_empty_text_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_empty_text_percent, Unset):
            monthly_partition_empty_text_percent = (
                self.monthly_partition_empty_text_percent.to_dict()
            )

        monthly_partition_whitespace_text_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_whitespace_text_percent, Unset):
            monthly_partition_whitespace_text_percent = (
                self.monthly_partition_whitespace_text_percent.to_dict()
            )

        monthly_partition_null_placeholder_text_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_null_placeholder_text_percent, Unset):
            monthly_partition_null_placeholder_text_percent = (
                self.monthly_partition_null_placeholder_text_percent.to_dict()
            )

        monthly_partition_text_surrounded_by_whitespace_found: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_surrounded_by_whitespace_found, Unset
        ):
            monthly_partition_text_surrounded_by_whitespace_found = (
                self.monthly_partition_text_surrounded_by_whitespace_found.to_dict()
            )

        monthly_partition_text_surrounded_by_whitespace_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_surrounded_by_whitespace_percent, Unset
        ):
            monthly_partition_text_surrounded_by_whitespace_percent = (
                self.monthly_partition_text_surrounded_by_whitespace_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_partition_empty_text_found is not UNSET:
            field_dict["monthly_partition_empty_text_found"] = (
                monthly_partition_empty_text_found
            )
        if monthly_partition_whitespace_text_found is not UNSET:
            field_dict["monthly_partition_whitespace_text_found"] = (
                monthly_partition_whitespace_text_found
            )
        if monthly_partition_null_placeholder_text_found is not UNSET:
            field_dict["monthly_partition_null_placeholder_text_found"] = (
                monthly_partition_null_placeholder_text_found
            )
        if monthly_partition_empty_text_percent is not UNSET:
            field_dict["monthly_partition_empty_text_percent"] = (
                monthly_partition_empty_text_percent
            )
        if monthly_partition_whitespace_text_percent is not UNSET:
            field_dict["monthly_partition_whitespace_text_percent"] = (
                monthly_partition_whitespace_text_percent
            )
        if monthly_partition_null_placeholder_text_percent is not UNSET:
            field_dict["monthly_partition_null_placeholder_text_percent"] = (
                monthly_partition_null_placeholder_text_percent
            )
        if monthly_partition_text_surrounded_by_whitespace_found is not UNSET:
            field_dict["monthly_partition_text_surrounded_by_whitespace_found"] = (
                monthly_partition_text_surrounded_by_whitespace_found
            )
        if monthly_partition_text_surrounded_by_whitespace_percent is not UNSET:
            field_dict["monthly_partition_text_surrounded_by_whitespace_percent"] = (
                monthly_partition_text_surrounded_by_whitespace_percent
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_whitespace_empty_text_found_check_spec import (
            ColumnWhitespaceEmptyTextFoundCheckSpec,
        )
        from ..models.column_whitespace_empty_text_percent_check_spec import (
            ColumnWhitespaceEmptyTextPercentCheckSpec,
        )
        from ..models.column_whitespace_monthly_partitioned_checks_spec_custom_checks import (
            ColumnWhitespaceMonthlyPartitionedChecksSpecCustomChecks,
        )
        from ..models.column_whitespace_null_placeholder_text_found_check_spec import (
            ColumnWhitespaceNullPlaceholderTextFoundCheckSpec,
        )
        from ..models.column_whitespace_null_placeholder_text_percent_check_spec import (
            ColumnWhitespaceNullPlaceholderTextPercentCheckSpec,
        )
        from ..models.column_whitespace_text_surrounded_by_whitespace_found_check_spec import (
            ColumnWhitespaceTextSurroundedByWhitespaceFoundCheckSpec,
        )
        from ..models.column_whitespace_text_surrounded_by_whitespace_percent_check_spec import (
            ColumnWhitespaceTextSurroundedByWhitespacePercentCheckSpec,
        )
        from ..models.column_whitespace_whitespace_text_found_check_spec import (
            ColumnWhitespaceWhitespaceTextFoundCheckSpec,
        )
        from ..models.column_whitespace_whitespace_text_percent_check_spec import (
            ColumnWhitespaceWhitespaceTextPercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnWhitespaceMonthlyPartitionedChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnWhitespaceMonthlyPartitionedChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _monthly_partition_empty_text_found = d.pop(
            "monthly_partition_empty_text_found", UNSET
        )
        monthly_partition_empty_text_found: Union[
            Unset, ColumnWhitespaceEmptyTextFoundCheckSpec
        ]
        if isinstance(_monthly_partition_empty_text_found, Unset):
            monthly_partition_empty_text_found = UNSET
        else:
            monthly_partition_empty_text_found = (
                ColumnWhitespaceEmptyTextFoundCheckSpec.from_dict(
                    _monthly_partition_empty_text_found
                )
            )

        _monthly_partition_whitespace_text_found = d.pop(
            "monthly_partition_whitespace_text_found", UNSET
        )
        monthly_partition_whitespace_text_found: Union[
            Unset, ColumnWhitespaceWhitespaceTextFoundCheckSpec
        ]
        if isinstance(_monthly_partition_whitespace_text_found, Unset):
            monthly_partition_whitespace_text_found = UNSET
        else:
            monthly_partition_whitespace_text_found = (
                ColumnWhitespaceWhitespaceTextFoundCheckSpec.from_dict(
                    _monthly_partition_whitespace_text_found
                )
            )

        _monthly_partition_null_placeholder_text_found = d.pop(
            "monthly_partition_null_placeholder_text_found", UNSET
        )
        monthly_partition_null_placeholder_text_found: Union[
            Unset, ColumnWhitespaceNullPlaceholderTextFoundCheckSpec
        ]
        if isinstance(_monthly_partition_null_placeholder_text_found, Unset):
            monthly_partition_null_placeholder_text_found = UNSET
        else:
            monthly_partition_null_placeholder_text_found = (
                ColumnWhitespaceNullPlaceholderTextFoundCheckSpec.from_dict(
                    _monthly_partition_null_placeholder_text_found
                )
            )

        _monthly_partition_empty_text_percent = d.pop(
            "monthly_partition_empty_text_percent", UNSET
        )
        monthly_partition_empty_text_percent: Union[
            Unset, ColumnWhitespaceEmptyTextPercentCheckSpec
        ]
        if isinstance(_monthly_partition_empty_text_percent, Unset):
            monthly_partition_empty_text_percent = UNSET
        else:
            monthly_partition_empty_text_percent = (
                ColumnWhitespaceEmptyTextPercentCheckSpec.from_dict(
                    _monthly_partition_empty_text_percent
                )
            )

        _monthly_partition_whitespace_text_percent = d.pop(
            "monthly_partition_whitespace_text_percent", UNSET
        )
        monthly_partition_whitespace_text_percent: Union[
            Unset, ColumnWhitespaceWhitespaceTextPercentCheckSpec
        ]
        if isinstance(_monthly_partition_whitespace_text_percent, Unset):
            monthly_partition_whitespace_text_percent = UNSET
        else:
            monthly_partition_whitespace_text_percent = (
                ColumnWhitespaceWhitespaceTextPercentCheckSpec.from_dict(
                    _monthly_partition_whitespace_text_percent
                )
            )

        _monthly_partition_null_placeholder_text_percent = d.pop(
            "monthly_partition_null_placeholder_text_percent", UNSET
        )
        monthly_partition_null_placeholder_text_percent: Union[
            Unset, ColumnWhitespaceNullPlaceholderTextPercentCheckSpec
        ]
        if isinstance(_monthly_partition_null_placeholder_text_percent, Unset):
            monthly_partition_null_placeholder_text_percent = UNSET
        else:
            monthly_partition_null_placeholder_text_percent = (
                ColumnWhitespaceNullPlaceholderTextPercentCheckSpec.from_dict(
                    _monthly_partition_null_placeholder_text_percent
                )
            )

        _monthly_partition_text_surrounded_by_whitespace_found = d.pop(
            "monthly_partition_text_surrounded_by_whitespace_found", UNSET
        )
        monthly_partition_text_surrounded_by_whitespace_found: Union[
            Unset, ColumnWhitespaceTextSurroundedByWhitespaceFoundCheckSpec
        ]
        if isinstance(_monthly_partition_text_surrounded_by_whitespace_found, Unset):
            monthly_partition_text_surrounded_by_whitespace_found = UNSET
        else:
            monthly_partition_text_surrounded_by_whitespace_found = (
                ColumnWhitespaceTextSurroundedByWhitespaceFoundCheckSpec.from_dict(
                    _monthly_partition_text_surrounded_by_whitespace_found
                )
            )

        _monthly_partition_text_surrounded_by_whitespace_percent = d.pop(
            "monthly_partition_text_surrounded_by_whitespace_percent", UNSET
        )
        monthly_partition_text_surrounded_by_whitespace_percent: Union[
            Unset, ColumnWhitespaceTextSurroundedByWhitespacePercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_surrounded_by_whitespace_percent, Unset):
            monthly_partition_text_surrounded_by_whitespace_percent = UNSET
        else:
            monthly_partition_text_surrounded_by_whitespace_percent = (
                ColumnWhitespaceTextSurroundedByWhitespacePercentCheckSpec.from_dict(
                    _monthly_partition_text_surrounded_by_whitespace_percent
                )
            )

        column_whitespace_monthly_partitioned_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_partition_empty_text_found=monthly_partition_empty_text_found,
            monthly_partition_whitespace_text_found=monthly_partition_whitespace_text_found,
            monthly_partition_null_placeholder_text_found=monthly_partition_null_placeholder_text_found,
            monthly_partition_empty_text_percent=monthly_partition_empty_text_percent,
            monthly_partition_whitespace_text_percent=monthly_partition_whitespace_text_percent,
            monthly_partition_null_placeholder_text_percent=monthly_partition_null_placeholder_text_percent,
            monthly_partition_text_surrounded_by_whitespace_found=monthly_partition_text_surrounded_by_whitespace_found,
            monthly_partition_text_surrounded_by_whitespace_percent=monthly_partition_text_surrounded_by_whitespace_percent,
        )

        column_whitespace_monthly_partitioned_checks_spec.additional_properties = d
        return column_whitespace_monthly_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="SpringErrorPayload")


@_attrs_define
class SpringErrorPayload:
    """Spring error payload that identifies the fields in the error returned by the REST API in case of unexpected errors
    (exceptions).

        Attributes:
            timestamp (Union[Unset, int]): Error timestamp as an epoch timestamp.
            status (Union[Unset, int]): Optional status code.
            error (Union[Unset, str]): Error name.
            exception (Union[Unset, str]): Optional exception.
            message (Union[Unset, str]): Exception's message.
            path (Union[Unset, str]): Exception's stack trace (optional).
    """

    timestamp: Union[Unset, int] = UNSET
    status: Union[Unset, int] = UNSET
    error: Union[Unset, str] = UNSET
    exception: Union[Unset, str] = UNSET
    message: Union[Unset, str] = UNSET
    path: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        timestamp = self.timestamp
        status = self.status
        error = self.error
        exception = self.exception
        message = self.message
        path = self.path

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if timestamp is not UNSET:
            field_dict["timestamp"] = timestamp
        if status is not UNSET:
            field_dict["status"] = status
        if error is not UNSET:
            field_dict["error"] = error
        if exception is not UNSET:
            field_dict["exception"] = exception
        if message is not UNSET:
            field_dict["message"] = message
        if path is not UNSET:
            field_dict["path"] = path

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        timestamp = d.pop("timestamp", UNSET)

        status = d.pop("status", UNSET)

        error = d.pop("error", UNSET)

        exception = d.pop("exception", UNSET)

        message = d.pop("message", UNSET)

        path = d.pop("path", UNSET)

        spring_error_payload = cls(
            timestamp=timestamp,
            status=status,
            error=error,
            exception=exception,
            message=message,
            path=path,
        )

        spring_error_payload.additional_properties = d
        return spring_error_payload

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.domain_connection_table_key import DomainConnectionTableKey
    from ..models.table_current_data_quality_status_model import (
        TableCurrentDataQualityStatusModel,
    )
    from ..models.table_lineage_flow_model import TableLineageFlowModel


T = TypeVar("T", bound="TableLineageModel")


@_attrs_define
class TableLineageModel:
    """The table lineage model that returns all upstream tables, downstream tables, or both.

    Attributes:
        relative_table (Union[Unset, DomainConnectionTableKey]): Table key that identifies a table in the data quality
            cache or a data lineage cache.
        relative_table_cumulative_quality_status (Union[Unset, TableCurrentDataQualityStatusModel]): The table's most
            recent data quality status. It is a summary of the results of the most recently executed data quality checks on
            the table. Verify the value of the highest_severity_level to see if there are any data quality issues on the
            table. The values of severity levels are: 0 - all data quality checks passed, 1 - a warning was detected, 2 - an
            error was detected, 3 - a fatal data quality issue was detected.
        flows (Union[Unset, List['TableLineageFlowModel']]): A list of data flows from source tables to direct target
            tables. Describes the data quality status of the source table.
        data_lineage_fully_loaded (Union[Unset, bool]): This flag tells if the data lineage was fully loaded. If any
            data flows are missing or the data quality status of some tables is missing, this flag will return false, which
            means that the data lineage must be loaded again.
    """

    relative_table: Union[Unset, "DomainConnectionTableKey"] = UNSET
    relative_table_cumulative_quality_status: Union[
        Unset, "TableCurrentDataQualityStatusModel"
    ] = UNSET
    flows: Union[Unset, List["TableLineageFlowModel"]] = UNSET
    data_lineage_fully_loaded: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        relative_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.relative_table, Unset):
            relative_table = self.relative_table.to_dict()

        relative_table_cumulative_quality_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.relative_table_cumulative_quality_status, Unset):
            relative_table_cumulative_quality_status = (
                self.relative_table_cumulative_quality_status.to_dict()
            )

        flows: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.flows, Unset):
            flows = []
            for flows_item_data in self.flows:
                flows_item = flows_item_data.to_dict()

                flows.append(flows_item)

        data_lineage_fully_loaded = self.data_lineage_fully_loaded

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if relative_table is not UNSET:
            field_dict["relative_table"] = relative_table
        if relative_table_cumulative_quality_status is not UNSET:
            field_dict["relative_table_cumulative_quality_status"] = (
                relative_table_cumulative_quality_status
            )
        if flows is not UNSET:
            field_dict["flows"] = flows
        if data_lineage_fully_loaded is not UNSET:
            field_dict["data_lineage_fully_loaded"] = data_lineage_fully_loaded

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.domain_connection_table_key import DomainConnectionTableKey
        from ..models.table_current_data_quality_status_model import (
            TableCurrentDataQualityStatusModel,
        )
        from ..models.table_lineage_flow_model import TableLineageFlowModel

        d = src_dict.copy()
        _relative_table = d.pop("relative_table", UNSET)
        relative_table: Union[Unset, DomainConnectionTableKey]
        if isinstance(_relative_table, Unset):
            relative_table = UNSET
        else:
            relative_table = DomainConnectionTableKey.from_dict(_relative_table)

        _relative_table_cumulative_quality_status = d.pop(
            "relative_table_cumulative_quality_status", UNSET
        )
        relative_table_cumulative_quality_status: Union[
            Unset, TableCurrentDataQualityStatusModel
        ]
        if isinstance(_relative_table_cumulative_quality_status, Unset):
            relative_table_cumulative_quality_status = UNSET
        else:
            relative_table_cumulative_quality_status = (
                TableCurrentDataQualityStatusModel.from_dict(
                    _relative_table_cumulative_quality_status
                )
            )

        flows = []
        _flows = d.pop("flows", UNSET)
        for flows_item_data in _flows or []:
            flows_item = TableLineageFlowModel.from_dict(flows_item_data)

            flows.append(flows_item)

        data_lineage_fully_loaded = d.pop("data_lineage_fully_loaded", UNSET)

        table_lineage_model = cls(
            relative_table=relative_table,
            relative_table_cumulative_quality_status=relative_table_cumulative_quality_status,
            flows=flows,
            data_lineage_fully_loaded=data_lineage_fully_loaded,
        )

        table_lineage_model.additional_properties = d
        return table_lineage_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_nulls_statistics_collectors_spec import (
        ColumnNullsStatisticsCollectorsSpec,
    )
    from ..models.column_range_statistics_collectors_spec import (
        ColumnRangeStatisticsCollectorsSpec,
    )
    from ..models.column_sampling_statistics_collectors_spec import (
        ColumnSamplingStatisticsCollectorsSpec,
    )
    from ..models.column_text_statistics_collectors_spec import (
        ColumnTextStatisticsCollectorsSpec,
    )
    from ..models.column_uniqueness_statistics_collectors_spec import (
        ColumnUniquenessStatisticsCollectorsSpec,
    )


T = TypeVar("T", bound="ColumnStatisticsCollectorsRootCategoriesSpec")


@_attrs_define
class ColumnStatisticsCollectorsRootCategoriesSpec:
    """
    Attributes:
        nulls (Union[Unset, ColumnNullsStatisticsCollectorsSpec]):
        text (Union[Unset, ColumnTextStatisticsCollectorsSpec]):
        uniqueness (Union[Unset, ColumnUniquenessStatisticsCollectorsSpec]):
        range_ (Union[Unset, ColumnRangeStatisticsCollectorsSpec]):
        sampling (Union[Unset, ColumnSamplingStatisticsCollectorsSpec]):
        strings (Union[Unset, ColumnTextStatisticsCollectorsSpec]):
    """

    nulls: Union[Unset, "ColumnNullsStatisticsCollectorsSpec"] = UNSET
    text: Union[Unset, "ColumnTextStatisticsCollectorsSpec"] = UNSET
    uniqueness: Union[Unset, "ColumnUniquenessStatisticsCollectorsSpec"] = UNSET
    range_: Union[Unset, "ColumnRangeStatisticsCollectorsSpec"] = UNSET
    sampling: Union[Unset, "ColumnSamplingStatisticsCollectorsSpec"] = UNSET
    strings: Union[Unset, "ColumnTextStatisticsCollectorsSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        nulls: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.nulls, Unset):
            nulls = self.nulls.to_dict()

        text: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text, Unset):
            text = self.text.to_dict()

        uniqueness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.uniqueness, Unset):
            uniqueness = self.uniqueness.to_dict()

        range_: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.range_, Unset):
            range_ = self.range_.to_dict()

        sampling: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.sampling, Unset):
            sampling = self.sampling.to_dict()

        strings: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.strings, Unset):
            strings = self.strings.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if nulls is not UNSET:
            field_dict["nulls"] = nulls
        if text is not UNSET:
            field_dict["text"] = text
        if uniqueness is not UNSET:
            field_dict["uniqueness"] = uniqueness
        if range_ is not UNSET:
            field_dict["range"] = range_
        if sampling is not UNSET:
            field_dict["sampling"] = sampling
        if strings is not UNSET:
            field_dict["strings"] = strings

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_nulls_statistics_collectors_spec import (
            ColumnNullsStatisticsCollectorsSpec,
        )
        from ..models.column_range_statistics_collectors_spec import (
            ColumnRangeStatisticsCollectorsSpec,
        )
        from ..models.column_sampling_statistics_collectors_spec import (
            ColumnSamplingStatisticsCollectorsSpec,
        )
        from ..models.column_text_statistics_collectors_spec import (
            ColumnTextStatisticsCollectorsSpec,
        )
        from ..models.column_uniqueness_statistics_collectors_spec import (
            ColumnUniquenessStatisticsCollectorsSpec,
        )

        d = src_dict.copy()
        _nulls = d.pop("nulls", UNSET)
        nulls: Union[Unset, ColumnNullsStatisticsCollectorsSpec]
        if isinstance(_nulls, Unset):
            nulls = UNSET
        else:
            nulls = ColumnNullsStatisticsCollectorsSpec.from_dict(_nulls)

        _text = d.pop("text", UNSET)
        text: Union[Unset, ColumnTextStatisticsCollectorsSpec]
        if isinstance(_text, Unset):
            text = UNSET
        else:
            text = ColumnTextStatisticsCollectorsSpec.from_dict(_text)

        _uniqueness = d.pop("uniqueness", UNSET)
        uniqueness: Union[Unset, ColumnUniquenessStatisticsCollectorsSpec]
        if isinstance(_uniqueness, Unset):
            uniqueness = UNSET
        else:
            uniqueness = ColumnUniquenessStatisticsCollectorsSpec.from_dict(_uniqueness)

        _range_ = d.pop("range", UNSET)
        range_: Union[Unset, ColumnRangeStatisticsCollectorsSpec]
        if isinstance(_range_, Unset):
            range_ = UNSET
        else:
            range_ = ColumnRangeStatisticsCollectorsSpec.from_dict(_range_)

        _sampling = d.pop("sampling", UNSET)
        sampling: Union[Unset, ColumnSamplingStatisticsCollectorsSpec]
        if isinstance(_sampling, Unset):
            sampling = UNSET
        else:
            sampling = ColumnSamplingStatisticsCollectorsSpec.from_dict(_sampling)

        _strings = d.pop("strings", UNSET)
        strings: Union[Unset, ColumnTextStatisticsCollectorsSpec]
        if isinstance(_strings, Unset):
            strings = UNSET
        else:
            strings = ColumnTextStatisticsCollectorsSpec.from_dict(_strings)

        column_statistics_collectors_root_categories_spec = cls(
            nulls=nulls,
            text=text,
            uniqueness=uniqueness,
            range_=range_,
            sampling=sampling,
            strings=strings,
        )

        column_statistics_collectors_root_categories_spec.additional_properties = d
        return column_statistics_collectors_root_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_search_filters import CheckSearchFilters
    from ..models.column_comparison_model import ColumnComparisonModel
    from ..models.compare_thresholds_model import CompareThresholdsModel
    from ..models.delete_stored_data_queue_job_parameters import (
        DeleteStoredDataQueueJobParameters,
    )
    from ..models.physical_table_name import PhysicalTableName
    from ..models.table_comparison_grouping_column_pair_model import (
        TableComparisonGroupingColumnPairModel,
    )


T = TypeVar("T", bound="TableComparisonModel")


@_attrs_define
class TableComparisonModel:
    """Model that contains the all editable information about a table-to-table comparison defined on a compared table.

    Attributes:
        table_comparison_configuration_name (Union[Unset, str]): The name of the table comparison configuration that is
            defined in the 'table_comparisons' node on the table specification.
        compared_connection (Union[Unset, str]): Compared connection name - the connection name to the data source that
            is compared (verified).
        compared_table (Union[Unset, PhysicalTableName]):
        reference_connection (Union[Unset, str]): Reference connection name - the connection name to the data source
            that has the reference data to compare to.
        reference_table (Union[Unset, PhysicalTableName]):
        compared_table_filter (Union[Unset, str]): Optional custom SQL filter expression that is added to the SQL query
            that retrieves the data from the compared table. This expression must be a SQL expression that will be added to
            the WHERE clause when querying the compared table.
        reference_table_filter (Union[Unset, str]): Optional custom SQL filter expression that is added to the SQL query
            that retrieves the data from the reference table (the source of truth). This expression must be a SQL expression
            that will be added to the WHERE clause when querying the reference table.
        grouping_columns (Union[Unset, List['TableComparisonGroupingColumnPairModel']]): List of column pairs from both
            the compared table and the reference table that are used in a GROUP BY clause  for grouping both the compared
            table and the reference table (the source of truth). The columns are used in the next of the table comparison to
            join the results of data groups (row counts, sums of columns) between the compared table and the reference table
            to compare the differences.
        default_compare_thresholds (Union[Unset, CompareThresholdsModel]): Model with the compare threshold levels for
            raising data quality issues at different severity levels when the difference between the compared (tested) table
            and the reference table (the source of truth) exceed given thresholds as a percentage of difference between the
            actual value and the expected value from the reference table.
        compare_row_count (Union[Unset, CompareThresholdsModel]): Model with the compare threshold levels for raising
            data quality issues at different severity levels when the difference between the compared (tested) table and the
            reference table (the source of truth) exceed given thresholds as a percentage of difference between the actual
            value and the expected value from the reference table.
        compare_column_count (Union[Unset, CompareThresholdsModel]): Model with the compare threshold levels for raising
            data quality issues at different severity levels when the difference between the compared (tested) table and the
            reference table (the source of truth) exceed given thresholds as a percentage of difference between the actual
            value and the expected value from the reference table.
        supports_compare_column_count (Union[Unset, bool]): Boolean flag that decides if this comparison type supports
            comparing the column count between tables. Partitioned table comparisons do not support comparing the column
            counts.
        columns (Union[Unset, List['ColumnComparisonModel']]): The list of compared columns, their matching reference
            column and the enabled comparisons.
        compare_table_run_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
            identifies which checks on which tables and columns should be executed.
        compare_table_clean_data_job_template (Union[Unset, DeleteStoredDataQueueJobParameters]):
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete the table
            comparison.
        can_run_compare_checks (Union[Unset, bool]): Boolean flag that decides if the current user can run comparison
            checks.
        can_delete_data (Union[Unset, bool]): Boolean flag that decides if the current user can delete data (results).
    """

    table_comparison_configuration_name: Union[Unset, str] = UNSET
    compared_connection: Union[Unset, str] = UNSET
    compared_table: Union[Unset, "PhysicalTableName"] = UNSET
    reference_connection: Union[Unset, str] = UNSET
    reference_table: Union[Unset, "PhysicalTableName"] = UNSET
    compared_table_filter: Union[Unset, str] = UNSET
    reference_table_filter: Union[Unset, str] = UNSET
    grouping_columns: Union[Unset, List["TableComparisonGroupingColumnPairModel"]] = (
        UNSET
    )
    default_compare_thresholds: Union[Unset, "CompareThresholdsModel"] = UNSET
    compare_row_count: Union[Unset, "CompareThresholdsModel"] = UNSET
    compare_column_count: Union[Unset, "CompareThresholdsModel"] = UNSET
    supports_compare_column_count: Union[Unset, bool] = UNSET
    columns: Union[Unset, List["ColumnComparisonModel"]] = UNSET
    compare_table_run_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    compare_table_clean_data_job_template: Union[
        Unset, "DeleteStoredDataQueueJobParameters"
    ] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    can_run_compare_checks: Union[Unset, bool] = UNSET
    can_delete_data: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        table_comparison_configuration_name = self.table_comparison_configuration_name
        compared_connection = self.compared_connection
        compared_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compared_table, Unset):
            compared_table = self.compared_table.to_dict()

        reference_connection = self.reference_connection
        reference_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.reference_table, Unset):
            reference_table = self.reference_table.to_dict()

        compared_table_filter = self.compared_table_filter
        reference_table_filter = self.reference_table_filter
        grouping_columns: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.grouping_columns, Unset):
            grouping_columns = []
            for grouping_columns_item_data in self.grouping_columns:
                grouping_columns_item = grouping_columns_item_data.to_dict()

                grouping_columns.append(grouping_columns_item)

        default_compare_thresholds: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.default_compare_thresholds, Unset):
            default_compare_thresholds = self.default_compare_thresholds.to_dict()

        compare_row_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_row_count, Unset):
            compare_row_count = self.compare_row_count.to_dict()

        compare_column_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_column_count, Unset):
            compare_column_count = self.compare_column_count.to_dict()

        supports_compare_column_count = self.supports_compare_column_count
        columns: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.columns, Unset):
            columns = []
            for columns_item_data in self.columns:
                columns_item = columns_item_data.to_dict()

                columns.append(columns_item)

        compare_table_run_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_table_run_checks_job_template, Unset):
            compare_table_run_checks_job_template = (
                self.compare_table_run_checks_job_template.to_dict()
            )

        compare_table_clean_data_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_table_clean_data_job_template, Unset):
            compare_table_clean_data_job_template = (
                self.compare_table_clean_data_job_template.to_dict()
            )

        can_edit = self.can_edit
        can_run_compare_checks = self.can_run_compare_checks
        can_delete_data = self.can_delete_data

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if table_comparison_configuration_name is not UNSET:
            field_dict["table_comparison_configuration_name"] = (
                table_comparison_configuration_name
            )
        if compared_connection is not UNSET:
            field_dict["compared_connection"] = compared_connection
        if compared_table is not UNSET:
            field_dict["compared_table"] = compared_table
        if reference_connection is not UNSET:
            field_dict["reference_connection"] = reference_connection
        if reference_table is not UNSET:
            field_dict["reference_table"] = reference_table
        if compared_table_filter is not UNSET:
            field_dict["compared_table_filter"] = compared_table_filter
        if reference_table_filter is not UNSET:
            field_dict["reference_table_filter"] = reference_table_filter
        if grouping_columns is not UNSET:
            field_dict["grouping_columns"] = grouping_columns
        if default_compare_thresholds is not UNSET:
            field_dict["default_compare_thresholds"] = default_compare_thresholds
        if compare_row_count is not UNSET:
            field_dict["compare_row_count"] = compare_row_count
        if compare_column_count is not UNSET:
            field_dict["compare_column_count"] = compare_column_count
        if supports_compare_column_count is not UNSET:
            field_dict["supports_compare_column_count"] = supports_compare_column_count
        if columns is not UNSET:
            field_dict["columns"] = columns
        if compare_table_run_checks_job_template is not UNSET:
            field_dict["compare_table_run_checks_job_template"] = (
                compare_table_run_checks_job_template
            )
        if compare_table_clean_data_job_template is not UNSET:
            field_dict["compare_table_clean_data_job_template"] = (
                compare_table_clean_data_job_template
            )
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if can_run_compare_checks is not UNSET:
            field_dict["can_run_compare_checks"] = can_run_compare_checks
        if can_delete_data is not UNSET:
            field_dict["can_delete_data"] = can_delete_data

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_search_filters import CheckSearchFilters
        from ..models.column_comparison_model import ColumnComparisonModel
        from ..models.compare_thresholds_model import CompareThresholdsModel
        from ..models.delete_stored_data_queue_job_parameters import (
            DeleteStoredDataQueueJobParameters,
        )
        from ..models.physical_table_name import PhysicalTableName
        from ..models.table_comparison_grouping_column_pair_model import (
            TableComparisonGroupingColumnPairModel,
        )

        d = src_dict.copy()
        table_comparison_configuration_name = d.pop(
            "table_comparison_configuration_name", UNSET
        )

        compared_connection = d.pop("compared_connection", UNSET)

        _compared_table = d.pop("compared_table", UNSET)
        compared_table: Union[Unset, PhysicalTableName]
        if isinstance(_compared_table, Unset):
            compared_table = UNSET
        else:
            compared_table = PhysicalTableName.from_dict(_compared_table)

        reference_connection = d.pop("reference_connection", UNSET)

        _reference_table = d.pop("reference_table", UNSET)
        reference_table: Union[Unset, PhysicalTableName]
        if isinstance(_reference_table, Unset):
            reference_table = UNSET
        else:
            reference_table = PhysicalTableName.from_dict(_reference_table)

        compared_table_filter = d.pop("compared_table_filter", UNSET)

        reference_table_filter = d.pop("reference_table_filter", UNSET)

        grouping_columns = []
        _grouping_columns = d.pop("grouping_columns", UNSET)
        for grouping_columns_item_data in _grouping_columns or []:
            grouping_columns_item = TableComparisonGroupingColumnPairModel.from_dict(
                grouping_columns_item_data
            )

            grouping_columns.append(grouping_columns_item)

        _default_compare_thresholds = d.pop("default_compare_thresholds", UNSET)
        default_compare_thresholds: Union[Unset, CompareThresholdsModel]
        if isinstance(_default_compare_thresholds, Unset):
            default_compare_thresholds = UNSET
        else:
            default_compare_thresholds = CompareThresholdsModel.from_dict(
                _default_compare_thresholds
            )

        _compare_row_count = d.pop("compare_row_count", UNSET)
        compare_row_count: Union[Unset, CompareThresholdsModel]
        if isinstance(_compare_row_count, Unset):
            compare_row_count = UNSET
        else:
            compare_row_count = CompareThresholdsModel.from_dict(_compare_row_count)

        _compare_column_count = d.pop("compare_column_count", UNSET)
        compare_column_count: Union[Unset, CompareThresholdsModel]
        if isinstance(_compare_column_count, Unset):
            compare_column_count = UNSET
        else:
            compare_column_count = CompareThresholdsModel.from_dict(
                _compare_column_count
            )

        supports_compare_column_count = d.pop("supports_compare_column_count", UNSET)

        columns = []
        _columns = d.pop("columns", UNSET)
        for columns_item_data in _columns or []:
            columns_item = ColumnComparisonModel.from_dict(columns_item_data)

            columns.append(columns_item)

        _compare_table_run_checks_job_template = d.pop(
            "compare_table_run_checks_job_template", UNSET
        )
        compare_table_run_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_compare_table_run_checks_job_template, Unset):
            compare_table_run_checks_job_template = UNSET
        else:
            compare_table_run_checks_job_template = CheckSearchFilters.from_dict(
                _compare_table_run_checks_job_template
            )

        _compare_table_clean_data_job_template = d.pop(
            "compare_table_clean_data_job_template", UNSET
        )
        compare_table_clean_data_job_template: Union[
            Unset, DeleteStoredDataQueueJobParameters
        ]
        if isinstance(_compare_table_clean_data_job_template, Unset):
            compare_table_clean_data_job_template = UNSET
        else:
            compare_table_clean_data_job_template = (
                DeleteStoredDataQueueJobParameters.from_dict(
                    _compare_table_clean_data_job_template
                )
            )

        can_edit = d.pop("can_edit", UNSET)

        can_run_compare_checks = d.pop("can_run_compare_checks", UNSET)

        can_delete_data = d.pop("can_delete_data", UNSET)

        table_comparison_model = cls(
            table_comparison_configuration_name=table_comparison_configuration_name,
            compared_connection=compared_connection,
            compared_table=compared_table,
            reference_connection=reference_connection,
            reference_table=reference_table,
            compared_table_filter=compared_table_filter,
            reference_table_filter=reference_table_filter,
            grouping_columns=grouping_columns,
            default_compare_thresholds=default_compare_thresholds,
            compare_row_count=compare_row_count,
            compare_column_count=compare_column_count,
            supports_compare_column_count=supports_compare_column_count,
            columns=columns,
            compare_table_run_checks_job_template=compare_table_run_checks_job_template,
            compare_table_clean_data_job_template=compare_table_clean_data_job_template,
            can_edit=can_edit,
            can_run_compare_checks=can_run_compare_checks,
            can_delete_data=can_delete_data,
        )

        table_comparison_model.additional_properties = d
        return table_comparison_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.provider_sensor_list_model import ProviderSensorListModel


T = TypeVar("T", bound="SensorListModel")


@_attrs_define
class SensorListModel:
    """Sensor list model

    Attributes:
        sensor_name (Union[Unset, str]): Sensor name, excluding the parent folder.
        full_sensor_name (Union[Unset, str]): Full sensor name, including the folder path within the "sensors" folder
            where the sensor definitions are stored. This is the unique identifier of the sensor.
        custom (Union[Unset, bool]): This sensor has is a custom sensor or was customized by the user. This is a read-
            only flag.
        built_in (Union[Unset, bool]): This sensor is provided with DQOps as a built-in sensor. This is a read-only
            flag.
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
        provider_sensors (Union[Unset, List['ProviderSensorListModel']]): List of provider (database) specific models.
        yaml_parsing_error (Union[Unset, str]): Optional parsing error that was captured when parsing the YAML file.
            This field is null when the YAML file is valid. If an error was captured, this field returns the file parsing
            error message and the file location.
    """

    sensor_name: Union[Unset, str] = UNSET
    full_sensor_name: Union[Unset, str] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    provider_sensors: Union[Unset, List["ProviderSensorListModel"]] = UNSET
    yaml_parsing_error: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sensor_name = self.sensor_name
        full_sensor_name = self.full_sensor_name
        custom = self.custom
        built_in = self.built_in
        can_edit = self.can_edit
        provider_sensors: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.provider_sensors, Unset):
            provider_sensors = []
            for provider_sensors_item_data in self.provider_sensors:
                provider_sensors_item = provider_sensors_item_data.to_dict()

                provider_sensors.append(provider_sensors_item)

        yaml_parsing_error = self.yaml_parsing_error

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if sensor_name is not UNSET:
            field_dict["sensor_name"] = sensor_name
        if full_sensor_name is not UNSET:
            field_dict["full_sensor_name"] = full_sensor_name
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["built_in"] = built_in
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if provider_sensors is not UNSET:
            field_dict["provider_sensors"] = provider_sensors
        if yaml_parsing_error is not UNSET:
            field_dict["yaml_parsing_error"] = yaml_parsing_error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.provider_sensor_list_model import ProviderSensorListModel

        d = src_dict.copy()
        sensor_name = d.pop("sensor_name", UNSET)

        full_sensor_name = d.pop("full_sensor_name", UNSET)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("built_in", UNSET)

        can_edit = d.pop("can_edit", UNSET)

        provider_sensors = []
        _provider_sensors = d.pop("provider_sensors", UNSET)
        for provider_sensors_item_data in _provider_sensors or []:
            provider_sensors_item = ProviderSensorListModel.from_dict(
                provider_sensors_item_data
            )

            provider_sensors.append(provider_sensors_item)

        yaml_parsing_error = d.pop("yaml_parsing_error", UNSET)

        sensor_list_model = cls(
            sensor_name=sensor_name,
            full_sensor_name=full_sensor_name,
            custom=custom,
            built_in=built_in,
            can_edit=can_edit,
            provider_sensors=provider_sensors,
            yaml_parsing_error=yaml_parsing_error,
        )

        sensor_list_model.additional_properties = d
        return sensor_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_spec import TableSpec


T = TypeVar("T", bound="TableModel")


@_attrs_define
class TableModel:
    """Full table model, including all nested objects like columns or checks.

    Attributes:
        connection_name (Union[Unset, str]): Connection name.
        table_hash (Union[Unset, int]): Table hash that identifies the table using a unique hash code.
        spec (Union[Unset, TableSpec]):
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
        yaml_parsing_error (Union[Unset, str]): Optional parsing error that was captured when parsing the YAML file.
            This field is null when the YAML file is valid. If an error was captured, this field returns the file parsing
            error message and the file location.
    """

    connection_name: Union[Unset, str] = UNSET
    table_hash: Union[Unset, int] = UNSET
    spec: Union[Unset, "TableSpec"] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    yaml_parsing_error: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        table_hash = self.table_hash
        spec: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.spec, Unset):
            spec = self.spec.to_dict()

        can_edit = self.can_edit
        yaml_parsing_error = self.yaml_parsing_error

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if table_hash is not UNSET:
            field_dict["table_hash"] = table_hash
        if spec is not UNSET:
            field_dict["spec"] = spec
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if yaml_parsing_error is not UNSET:
            field_dict["yaml_parsing_error"] = yaml_parsing_error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_spec import TableSpec

        d = src_dict.copy()
        connection_name = d.pop("connection_name", UNSET)

        table_hash = d.pop("table_hash", UNSET)

        _spec = d.pop("spec", UNSET)
        spec: Union[Unset, TableSpec]
        if isinstance(_spec, Unset):
            spec = UNSET
        else:
            spec = TableSpec.from_dict(_spec)

        can_edit = d.pop("can_edit", UNSET)

        yaml_parsing_error = d.pop("yaml_parsing_error", UNSET)

        table_model = cls(
            connection_name=connection_name,
            table_hash=table_hash,
            spec=spec,
            can_edit=can_edit,
            yaml_parsing_error=yaml_parsing_error,
        )

        table_model.additional_properties = d
        return table_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.provider_sensor_model import ProviderSensorModel
    from ..models.sensor_definition_spec import SensorDefinitionSpec


T = TypeVar("T", bound="SensorModel")


@_attrs_define
class SensorModel:
    """Sensor model that describes the configuration of a single built-in or custom sensor.

    Attributes:
        full_sensor_name (Union[Unset, str]): Full sensor name.
        sensor_definition_spec (Union[Unset, SensorDefinitionSpec]):
        provider_sensor_list (Union[Unset, List['ProviderSensorModel']]): Provider sensors list with provider specific
            sensor definitions.
        custom (Union[Unset, bool]): Whether the sensor is a User Home sensor
        built_in (Union[Unset, bool]): This is a DQOps built-in sensor, whose parameters cannot be changed.
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
        yaml_parsing_error (Union[Unset, str]): Optional parsing error that was captured when parsing the YAML file.
            This field is null when the YAML file is valid. If an error was captured, this field returns the file parsing
            error message and the file location.
    """

    full_sensor_name: Union[Unset, str] = UNSET
    sensor_definition_spec: Union[Unset, "SensorDefinitionSpec"] = UNSET
    provider_sensor_list: Union[Unset, List["ProviderSensorModel"]] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    yaml_parsing_error: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        full_sensor_name = self.full_sensor_name
        sensor_definition_spec: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.sensor_definition_spec, Unset):
            sensor_definition_spec = self.sensor_definition_spec.to_dict()

        provider_sensor_list: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.provider_sensor_list, Unset):
            provider_sensor_list = []
            for provider_sensor_list_item_data in self.provider_sensor_list:
                provider_sensor_list_item = provider_sensor_list_item_data.to_dict()

                provider_sensor_list.append(provider_sensor_list_item)

        custom = self.custom
        built_in = self.built_in
        can_edit = self.can_edit
        yaml_parsing_error = self.yaml_parsing_error

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if full_sensor_name is not UNSET:
            field_dict["full_sensor_name"] = full_sensor_name
        if sensor_definition_spec is not UNSET:
            field_dict["sensor_definition_spec"] = sensor_definition_spec
        if provider_sensor_list is not UNSET:
            field_dict["provider_sensor_list"] = provider_sensor_list
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["built_in"] = built_in
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if yaml_parsing_error is not UNSET:
            field_dict["yaml_parsing_error"] = yaml_parsing_error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.provider_sensor_model import ProviderSensorModel
        from ..models.sensor_definition_spec import SensorDefinitionSpec

        d = src_dict.copy()
        full_sensor_name = d.pop("full_sensor_name", UNSET)

        _sensor_definition_spec = d.pop("sensor_definition_spec", UNSET)
        sensor_definition_spec: Union[Unset, SensorDefinitionSpec]
        if isinstance(_sensor_definition_spec, Unset):
            sensor_definition_spec = UNSET
        else:
            sensor_definition_spec = SensorDefinitionSpec.from_dict(
                _sensor_definition_spec
            )

        provider_sensor_list = []
        _provider_sensor_list = d.pop("provider_sensor_list", UNSET)
        for provider_sensor_list_item_data in _provider_sensor_list or []:
            provider_sensor_list_item = ProviderSensorModel.from_dict(
                provider_sensor_list_item_data
            )

            provider_sensor_list.append(provider_sensor_list_item)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("built_in", UNSET)

        can_edit = d.pop("can_edit", UNSET)

        yaml_parsing_error = d.pop("yaml_parsing_error", UNSET)

        sensor_model = cls(
            full_sensor_name=full_sensor_name,
            sensor_definition_spec=sensor_definition_spec,
            provider_sensor_list=provider_sensor_list,
            custom=custom,
            built_in=built_in,
            can_edit=can_edit,
            yaml_parsing_error=yaml_parsing_error,
        )

        sensor_model.additional_properties = d
        return sensor_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.check_time_scale import CheckTimeScale
from ...models.table_current_data_quality_status_model import (
    TableCurrentDataQualityStatusModel,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    months: Union[Unset, None, int] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    profiling: Union[Unset, None, bool] = UNSET,
    monitoring: Union[Unset, None, bool] = UNSET,
    partitioned: Union[Unset, None, bool] = UNSET,
    check_time_scale: Union[Unset, None, CheckTimeScale] = UNSET,
    data_group: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    quality_dimension: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:

    pass

    params: Dict[str, Any] = {}
    params["months"] = months

    json_since: Union[Unset, None, str] = UNSET
    if not isinstance(since, Unset):
        json_since = since.isoformat() if since else None

    params["since"] = json_since

    params["profiling"] = profiling

    params["monitoring"] = monitoring

    params["partitioned"] = partitioned

    json_check_time_scale: Union[Unset, None, str] = UNSET
    if not isinstance(check_time_scale, Unset):
        json_check_time_scale = check_time_scale.value if check_time_scale else None

    params["checkTimeScale"] = json_check_time_scale

    params["dataGroup"] = data_group

    params["checkName"] = check_name

    params["category"] = category

    params["tableComparison"] = table_comparison

    params["qualityDimension"] = quality_dimension

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "api/connections/{connectionName}/schemas/{schemaName}/tables/{tableName}/status".format(
            connectionName=connection_name,
            schemaName=schema_name,
            tableName=table_name,
        ),
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[TableCurrentDataQualityStatusModel]:
    if response.status_code == HTTPStatus.OK:
        response_200 = TableCurrentDataQualityStatusModel.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[TableCurrentDataQualityStatusModel]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: AuthenticatedClient,
    months: Union[Unset, None, int] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    profiling: Union[Unset, None, bool] = UNSET,
    monitoring: Union[Unset, None, bool] = UNSET,
    partitioned: Union[Unset, None, bool] = UNSET,
    check_time_scale: Union[Unset, None, CheckTimeScale] = UNSET,
    data_group: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    quality_dimension: Union[Unset, None, str] = UNSET,
) -> Response[TableCurrentDataQualityStatusModel]:
    """getTableDataQualityStatus

     Read the most recent results of executed data quality checks on the table and return the current
    table's data quality status - the number of failed data quality checks if the table has active data
    quality issues. Also returns the names of data quality checks that did not pass most recently. This
    operation verifies only the status of the most recently executed data quality checks. Previous data
    quality issues are not counted.

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        months (Union[Unset, None, int]):
        since (Union[Unset, None, datetime.datetime]):
        profiling (Union[Unset, None, bool]):
        monitoring (Union[Unset, None, bool]):
        partitioned (Union[Unset, None, bool]):
        check_time_scale (Union[Unset, None, CheckTimeScale]):
        data_group (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):
        category (Union[Unset, None, str]):
        table_comparison (Union[Unset, None, str]):
        quality_dimension (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TableCurrentDataQualityStatusModel]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        months=months,
        since=since,
        profiling=profiling,
        monitoring=monitoring,
        partitioned=partitioned,
        check_time_scale=check_time_scale,
        data_group=data_group,
        check_name=check_name,
        category=category,
        table_comparison=table_comparison,
        quality_dimension=quality_dimension,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: AuthenticatedClient,
    months: Union[Unset, None, int] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    profiling: Union[Unset, None, bool] = UNSET,
    monitoring: Union[Unset, None, bool] = UNSET,
    partitioned: Union[Unset, None, bool] = UNSET,
    check_time_scale: Union[Unset, None, CheckTimeScale] = UNSET,
    data_group: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    quality_dimension: Union[Unset, None, str] = UNSET,
) -> Optional[TableCurrentDataQualityStatusModel]:
    """getTableDataQualityStatus

     Read the most recent results of executed data quality checks on the table and return the current
    table's data quality status - the number of failed data quality checks if the table has active data
    quality issues. Also returns the names of data quality checks that did not pass most recently. This
    operation verifies only the status of the most recently executed data quality checks. Previous data
    quality issues are not counted.

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        months (Union[Unset, None, int]):
        since (Union[Unset, None, datetime.datetime]):
        profiling (Union[Unset, None, bool]):
        monitoring (Union[Unset, None, bool]):
        partitioned (Union[Unset, None, bool]):
        check_time_scale (Union[Unset, None, CheckTimeScale]):
        data_group (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):
        category (Union[Unset, None, str]):
        table_comparison (Union[Unset, None, str]):
        quality_dimension (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TableCurrentDataQualityStatusModel
    """

    return sync_detailed(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        client=client,
        months=months,
        since=since,
        profiling=profiling,
        monitoring=monitoring,
        partitioned=partitioned,
        check_time_scale=check_time_scale,
        data_group=data_group,
        check_name=check_name,
        category=category,
        table_comparison=table_comparison,
        quality_dimension=quality_dimension,
    ).parsed


async def asyncio_detailed(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: AuthenticatedClient,
    months: Union[Unset, None, int] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    profiling: Union[Unset, None, bool] = UNSET,
    monitoring: Union[Unset, None, bool] = UNSET,
    partitioned: Union[Unset, None, bool] = UNSET,
    check_time_scale: Union[Unset, None, CheckTimeScale] = UNSET,
    data_group: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    quality_dimension: Union[Unset, None, str] = UNSET,
) -> Response[TableCurrentDataQualityStatusModel]:
    """getTableDataQualityStatus

     Read the most recent results of executed data quality checks on the table and return the current
    table's data quality status - the number of failed data quality checks if the table has active data
    quality issues. Also returns the names of data quality checks that did not pass most recently. This
    operation verifies only the status of the most recently executed data quality checks. Previous data
    quality issues are not counted.

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        months (Union[Unset, None, int]):
        since (Union[Unset, None, datetime.datetime]):
        profiling (Union[Unset, None, bool]):
        monitoring (Union[Unset, None, bool]):
        partitioned (Union[Unset, None, bool]):
        check_time_scale (Union[Unset, None, CheckTimeScale]):
        data_group (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):
        category (Union[Unset, None, str]):
        table_comparison (Union[Unset, None, str]):
        quality_dimension (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TableCurrentDataQualityStatusModel]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        months=months,
        since=since,
        profiling=profiling,
        monitoring=monitoring,
        partitioned=partitioned,
        check_time_scale=check_time_scale,
        data_group=data_group,
        check_name=check_name,
        category=category,
        table_comparison=table_comparison,
        quality_dimension=quality_dimension,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: AuthenticatedClient,
    months: Union[Unset, None, int] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    profiling: Union[Unset, None, bool] = UNSET,
    monitoring: Union[Unset, None, bool] = UNSET,
    partitioned: Union[Unset, None, bool] = UNSET,
    check_time_scale: Union[Unset, None, CheckTimeScale] = UNSET,
    data_group: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    quality_dimension: Union[Unset, None, str] = UNSET,
) -> Optional[TableCurrentDataQualityStatusModel]:
    """getTableDataQualityStatus

     Read the most recent results of executed data quality checks on the table and return the current
    table's data quality status - the number of failed data quality checks if the table has active data
    quality issues. Also returns the names of data quality checks that did not pass most recently. This
    operation verifies only the status of the most recently executed data quality checks. Previous data
    quality issues are not counted.

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        months (Union[Unset, None, int]):
        since (Union[Unset, None, datetime.datetime]):
        profiling (Union[Unset, None, bool]):
        monitoring (Union[Unset, None, bool]):
        partitioned (Union[Unset, None, bool]):
        check_time_scale (Union[Unset, None, CheckTimeScale]):
        data_group (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):
        category (Union[Unset, None, str]):
        table_comparison (Union[Unset, None, str]):
        quality_dimension (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TableCurrentDataQualityStatusModel
    """

    return (
        await asyncio_detailed(
            connection_name=connection_name,
            schema_name=schema_name,
            table_name=table_name,
            client=client,
            months=months,
            since=since,
            profiling=profiling,
            monitoring=monitoring,
            partitioned=partitioned,
            check_time_scale=check_time_scale,
            data_group=data_group,
            check_name=check_name,
            category=category,
            table_comparison=table_comparison,
            quality_dimension=quality_dimension,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.comparison_check_result_model import ComparisonCheckResultModel


T = TypeVar("T", bound="TableComparisonColumnResultsModelColumnComparisonResults")


@_attrs_define
class TableComparisonColumnResultsModelColumnComparisonResults:
    """The dictionary of comparison results between the tables for the specific column. The keys for the dictionary are
    check names. The values are summaries of the most recent comparison on this column.

    """

    additional_properties: Dict[str, "ComparisonCheckResultModel"] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        pass

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.comparison_check_result_model import ComparisonCheckResultModel

        d = src_dict.copy()
        table_comparison_column_results_model_column_comparison_results = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = ComparisonCheckResultModel.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        table_comparison_column_results_model_column_comparison_results.additional_properties = (
            additional_properties
        )
        return table_comparison_column_results_model_column_comparison_results

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "ComparisonCheckResultModel":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "ComparisonCheckResultModel") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_integer_in_range_percent_check_spec import (
        ColumnIntegerInRangePercentCheckSpec,
    )
    from ..models.column_invalid_latitude_count_check_spec import (
        ColumnInvalidLatitudeCountCheckSpec,
    )
    from ..models.column_invalid_longitude_count_check_spec import (
        ColumnInvalidLongitudeCountCheckSpec,
    )
    from ..models.column_max_in_range_check_spec import ColumnMaxInRangeCheckSpec
    from ..models.column_mean_in_range_check_spec import ColumnMeanInRangeCheckSpec
    from ..models.column_median_in_range_check_spec import ColumnMedianInRangeCheckSpec
    from ..models.column_min_in_range_check_spec import ColumnMinInRangeCheckSpec
    from ..models.column_negative_count_check_spec import ColumnNegativeCountCheckSpec
    from ..models.column_negative_percent_check_spec import (
        ColumnNegativePercentCheckSpec,
    )
    from ..models.column_non_negative_count_check_spec import (
        ColumnNonNegativeCountCheckSpec,
    )
    from ..models.column_non_negative_percent_check_spec import (
        ColumnNonNegativePercentCheckSpec,
    )
    from ..models.column_number_above_max_value_check_spec import (
        ColumnNumberAboveMaxValueCheckSpec,
    )
    from ..models.column_number_above_max_value_percent_check_spec import (
        ColumnNumberAboveMaxValuePercentCheckSpec,
    )
    from ..models.column_number_below_min_value_check_spec import (
        ColumnNumberBelowMinValueCheckSpec,
    )
    from ..models.column_number_below_min_value_percent_check_spec import (
        ColumnNumberBelowMinValuePercentCheckSpec,
    )
    from ..models.column_number_in_range_percent_check_spec import (
        ColumnNumberInRangePercentCheckSpec,
    )
    from ..models.column_numeric_profiling_checks_spec_custom_checks import (
        ColumnNumericProfilingChecksSpecCustomChecks,
    )
    from ..models.column_percentile_10_in_range_check_spec import (
        ColumnPercentile10InRangeCheckSpec,
    )
    from ..models.column_percentile_25_in_range_check_spec import (
        ColumnPercentile25InRangeCheckSpec,
    )
    from ..models.column_percentile_75_in_range_check_spec import (
        ColumnPercentile75InRangeCheckSpec,
    )
    from ..models.column_percentile_90_in_range_check_spec import (
        ColumnPercentile90InRangeCheckSpec,
    )
    from ..models.column_percentile_in_range_check_spec import (
        ColumnPercentileInRangeCheckSpec,
    )
    from ..models.column_population_stddev_in_range_check_spec import (
        ColumnPopulationStddevInRangeCheckSpec,
    )
    from ..models.column_population_variance_in_range_check_spec import (
        ColumnPopulationVarianceInRangeCheckSpec,
    )
    from ..models.column_sample_stddev_in_range_check_spec import (
        ColumnSampleStddevInRangeCheckSpec,
    )
    from ..models.column_sample_variance_in_range_check_spec import (
        ColumnSampleVarianceInRangeCheckSpec,
    )
    from ..models.column_sum_in_range_check_spec import ColumnSumInRangeCheckSpec
    from ..models.column_valid_latitude_percent_check_spec import (
        ColumnValidLatitudePercentCheckSpec,
    )
    from ..models.column_valid_longitude_percent_check_spec import (
        ColumnValidLongitudePercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnNumericProfilingChecksSpec")


@_attrs_define
class ColumnNumericProfilingChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnNumericProfilingChecksSpecCustomChecks]): Dictionary of additional custom
            checks within this category. The keys are check names defined in the definition section. The sensor parameters
            and rules should match the type of the configured sensor and rule for the custom check.
        profile_number_below_min_value (Union[Unset, ColumnNumberBelowMinValueCheckSpec]):
        profile_number_above_max_value (Union[Unset, ColumnNumberAboveMaxValueCheckSpec]):
        profile_negative_values (Union[Unset, ColumnNegativeCountCheckSpec]):
        profile_negative_values_percent (Union[Unset, ColumnNegativePercentCheckSpec]):
        profile_number_below_min_value_percent (Union[Unset, ColumnNumberBelowMinValuePercentCheckSpec]):
        profile_number_above_max_value_percent (Union[Unset, ColumnNumberAboveMaxValuePercentCheckSpec]):
        profile_number_in_range_percent (Union[Unset, ColumnNumberInRangePercentCheckSpec]):
        profile_integer_in_range_percent (Union[Unset, ColumnIntegerInRangePercentCheckSpec]):
        profile_min_in_range (Union[Unset, ColumnMinInRangeCheckSpec]):
        profile_max_in_range (Union[Unset, ColumnMaxInRangeCheckSpec]):
        profile_sum_in_range (Union[Unset, ColumnSumInRangeCheckSpec]):
        profile_mean_in_range (Union[Unset, ColumnMeanInRangeCheckSpec]):
        profile_median_in_range (Union[Unset, ColumnMedianInRangeCheckSpec]):
        profile_percentile_in_range (Union[Unset, ColumnPercentileInRangeCheckSpec]):
        profile_percentile_10_in_range (Union[Unset, ColumnPercentile10InRangeCheckSpec]):
        profile_percentile_25_in_range (Union[Unset, ColumnPercentile25InRangeCheckSpec]):
        profile_percentile_75_in_range (Union[Unset, ColumnPercentile75InRangeCheckSpec]):
        profile_percentile_90_in_range (Union[Unset, ColumnPercentile90InRangeCheckSpec]):
        profile_sample_stddev_in_range (Union[Unset, ColumnSampleStddevInRangeCheckSpec]):
        profile_population_stddev_in_range (Union[Unset, ColumnPopulationStddevInRangeCheckSpec]):
        profile_sample_variance_in_range (Union[Unset, ColumnSampleVarianceInRangeCheckSpec]):
        profile_population_variance_in_range (Union[Unset, ColumnPopulationVarianceInRangeCheckSpec]):
        profile_invalid_latitude (Union[Unset, ColumnInvalidLatitudeCountCheckSpec]):
        profile_valid_latitude_percent (Union[Unset, ColumnValidLatitudePercentCheckSpec]):
        profile_invalid_longitude (Union[Unset, ColumnInvalidLongitudeCountCheckSpec]):
        profile_valid_longitude_percent (Union[Unset, ColumnValidLongitudePercentCheckSpec]):
        profile_non_negative_values (Union[Unset, ColumnNonNegativeCountCheckSpec]):
        profile_non_negative_values_percent (Union[Unset, ColumnNonNegativePercentCheckSpec]):
    """

    custom_checks: Union[Unset, "ColumnNumericProfilingChecksSpecCustomChecks"] = UNSET
    profile_number_below_min_value: Union[
        Unset, "ColumnNumberBelowMinValueCheckSpec"
    ] = UNSET
    profile_number_above_max_value: Union[
        Unset, "ColumnNumberAboveMaxValueCheckSpec"
    ] = UNSET
    profile_negative_values: Union[Unset, "ColumnNegativeCountCheckSpec"] = UNSET
    profile_negative_values_percent: Union[Unset, "ColumnNegativePercentCheckSpec"] = (
        UNSET
    )
    profile_number_below_min_value_percent: Union[
        Unset, "ColumnNumberBelowMinValuePercentCheckSpec"
    ] = UNSET
    profile_number_above_max_value_percent: Union[
        Unset, "ColumnNumberAboveMaxValuePercentCheckSpec"
    ] = UNSET
    profile_number_in_range_percent: Union[
        Unset, "ColumnNumberInRangePercentCheckSpec"
    ] = UNSET
    profile_integer_in_range_percent: Union[
        Unset, "ColumnIntegerInRangePercentCheckSpec"
    ] = UNSET
    profile_min_in_range: Union[Unset, "ColumnMinInRangeCheckSpec"] = UNSET
    profile_max_in_range: Union[Unset, "ColumnMaxInRangeCheckSpec"] = UNSET
    profile_sum_in_range: Union[Unset, "ColumnSumInRangeCheckSpec"] = UNSET
    profile_mean_in_range: Union[Unset, "ColumnMeanInRangeCheckSpec"] = UNSET
    profile_median_in_range: Union[Unset, "ColumnMedianInRangeCheckSpec"] = UNSET
    profile_percentile_in_range: Union[Unset, "ColumnPercentileInRangeCheckSpec"] = (
        UNSET
    )
    profile_percentile_10_in_range: Union[
        Unset, "ColumnPercentile10InRangeCheckSpec"
    ] = UNSET
    profile_percentile_25_in_range: Union[
        Unset, "ColumnPercentile25InRangeCheckSpec"
    ] = UNSET
    profile_percentile_75_in_range: Union[
        Unset, "ColumnPercentile75InRangeCheckSpec"
    ] = UNSET
    profile_percentile_90_in_range: Union[
        Unset, "ColumnPercentile90InRangeCheckSpec"
    ] = UNSET
    profile_sample_stddev_in_range: Union[
        Unset, "ColumnSampleStddevInRangeCheckSpec"
    ] = UNSET
    profile_population_stddev_in_range: Union[
        Unset, "ColumnPopulationStddevInRangeCheckSpec"
    ] = UNSET
    profile_sample_variance_in_range: Union[
        Unset, "ColumnSampleVarianceInRangeCheckSpec"
    ] = UNSET
    profile_population_variance_in_range: Union[
        Unset, "ColumnPopulationVarianceInRangeCheckSpec"
    ] = UNSET
    profile_invalid_latitude: Union[Unset, "ColumnInvalidLatitudeCountCheckSpec"] = (
        UNSET
    )
    profile_valid_latitude_percent: Union[
        Unset, "ColumnValidLatitudePercentCheckSpec"
    ] = UNSET
    profile_invalid_longitude: Union[Unset, "ColumnInvalidLongitudeCountCheckSpec"] = (
        UNSET
    )
    profile_valid_longitude_percent: Union[
        Unset, "ColumnValidLongitudePercentCheckSpec"
    ] = UNSET
    profile_non_negative_values: Union[Unset, "ColumnNonNegativeCountCheckSpec"] = UNSET
    profile_non_negative_values_percent: Union[
        Unset, "ColumnNonNegativePercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        profile_number_below_min_value: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_number_below_min_value, Unset):
            profile_number_below_min_value = (
                self.profile_number_below_min_value.to_dict()
            )

        profile_number_above_max_value: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_number_above_max_value, Unset):
            profile_number_above_max_value = (
                self.profile_number_above_max_value.to_dict()
            )

        profile_negative_values: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_negative_values, Unset):
            profile_negative_values = self.profile_negative_values.to_dict()

        profile_negative_values_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_negative_values_percent, Unset):
            profile_negative_values_percent = (
                self.profile_negative_values_percent.to_dict()
            )

        profile_number_below_min_value_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_number_below_min_value_percent, Unset):
            profile_number_below_min_value_percent = (
                self.profile_number_below_min_value_percent.to_dict()
            )

        profile_number_above_max_value_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_number_above_max_value_percent, Unset):
            profile_number_above_max_value_percent = (
                self.profile_number_above_max_value_percent.to_dict()
            )

        profile_number_in_range_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_number_in_range_percent, Unset):
            profile_number_in_range_percent = (
                self.profile_number_in_range_percent.to_dict()
            )

        profile_integer_in_range_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_integer_in_range_percent, Unset):
            profile_integer_in_range_percent = (
                self.profile_integer_in_range_percent.to_dict()
            )

        profile_min_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_min_in_range, Unset):
            profile_min_in_range = self.profile_min_in_range.to_dict()

        profile_max_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_max_in_range, Unset):
            profile_max_in_range = self.profile_max_in_range.to_dict()

        profile_sum_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sum_in_range, Unset):
            profile_sum_in_range = self.profile_sum_in_range.to_dict()

        profile_mean_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_mean_in_range, Unset):
            profile_mean_in_range = self.profile_mean_in_range.to_dict()

        profile_median_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_median_in_range, Unset):
            profile_median_in_range = self.profile_median_in_range.to_dict()

        profile_percentile_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_percentile_in_range, Unset):
            profile_percentile_in_range = self.profile_percentile_in_range.to_dict()

        profile_percentile_10_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_percentile_10_in_range, Unset):
            profile_percentile_10_in_range = (
                self.profile_percentile_10_in_range.to_dict()
            )

        profile_percentile_25_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_percentile_25_in_range, Unset):
            profile_percentile_25_in_range = (
                self.profile_percentile_25_in_range.to_dict()
            )

        profile_percentile_75_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_percentile_75_in_range, Unset):
            profile_percentile_75_in_range = (
                self.profile_percentile_75_in_range.to_dict()
            )

        profile_percentile_90_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_percentile_90_in_range, Unset):
            profile_percentile_90_in_range = (
                self.profile_percentile_90_in_range.to_dict()
            )

        profile_sample_stddev_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sample_stddev_in_range, Unset):
            profile_sample_stddev_in_range = (
                self.profile_sample_stddev_in_range.to_dict()
            )

        profile_population_stddev_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_population_stddev_in_range, Unset):
            profile_population_stddev_in_range = (
                self.profile_population_stddev_in_range.to_dict()
            )

        profile_sample_variance_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sample_variance_in_range, Unset):
            profile_sample_variance_in_range = (
                self.profile_sample_variance_in_range.to_dict()
            )

        profile_population_variance_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_population_variance_in_range, Unset):
            profile_population_variance_in_range = (
                self.profile_population_variance_in_range.to_dict()
            )

        profile_invalid_latitude: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_latitude, Unset):
            profile_invalid_latitude = self.profile_invalid_latitude.to_dict()

        profile_valid_latitude_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_valid_latitude_percent, Unset):
            profile_valid_latitude_percent = (
                self.profile_valid_latitude_percent.to_dict()
            )

        profile_invalid_longitude: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_longitude, Unset):
            profile_invalid_longitude = self.profile_invalid_longitude.to_dict()

        profile_valid_longitude_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_valid_longitude_percent, Unset):
            profile_valid_longitude_percent = (
                self.profile_valid_longitude_percent.to_dict()
            )

        profile_non_negative_values: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_non_negative_values, Unset):
            profile_non_negative_values = self.profile_non_negative_values.to_dict()

        profile_non_negative_values_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_non_negative_values_percent, Unset):
            profile_non_negative_values_percent = (
                self.profile_non_negative_values_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if profile_number_below_min_value is not UNSET:
            field_dict["profile_number_below_min_value"] = (
                profile_number_below_min_value
            )
        if profile_number_above_max_value is not UNSET:
            field_dict["profile_number_above_max_value"] = (
                profile_number_above_max_value
            )
        if profile_negative_values is not UNSET:
            field_dict["profile_negative_values"] = profile_negative_values
        if profile_negative_values_percent is not UNSET:
            field_dict["profile_negative_values_percent"] = (
                profile_negative_values_percent
            )
        if profile_number_below_min_value_percent is not UNSET:
            field_dict["profile_number_below_min_value_percent"] = (
                profile_number_below_min_value_percent
            )
        if profile_number_above_max_value_percent is not UNSET:
            field_dict["profile_number_above_max_value_percent"] = (
                profile_number_above_max_value_percent
            )
        if profile_number_in_range_percent is not UNSET:
            field_dict["profile_number_in_range_percent"] = (
                profile_number_in_range_percent
            )
        if profile_integer_in_range_percent is not UNSET:
            field_dict["profile_integer_in_range_percent"] = (
                profile_integer_in_range_percent
            )
        if profile_min_in_range is not UNSET:
            field_dict["profile_min_in_range"] = profile_min_in_range
        if profile_max_in_range is not UNSET:
            field_dict["profile_max_in_range"] = profile_max_in_range
        if profile_sum_in_range is not UNSET:
            field_dict["profile_sum_in_range"] = profile_sum_in_range
        if profile_mean_in_range is not UNSET:
            field_dict["profile_mean_in_range"] = profile_mean_in_range
        if profile_median_in_range is not UNSET:
            field_dict["profile_median_in_range"] = profile_median_in_range
        if profile_percentile_in_range is not UNSET:
            field_dict["profile_percentile_in_range"] = profile_percentile_in_range
        if profile_percentile_10_in_range is not UNSET:
            field_dict["profile_percentile_10_in_range"] = (
                profile_percentile_10_in_range
            )
        if profile_percentile_25_in_range is not UNSET:
            field_dict["profile_percentile_25_in_range"] = (
                profile_percentile_25_in_range
            )
        if profile_percentile_75_in_range is not UNSET:
            field_dict["profile_percentile_75_in_range"] = (
                profile_percentile_75_in_range
            )
        if profile_percentile_90_in_range is not UNSET:
            field_dict["profile_percentile_90_in_range"] = (
                profile_percentile_90_in_range
            )
        if profile_sample_stddev_in_range is not UNSET:
            field_dict["profile_sample_stddev_in_range"] = (
                profile_sample_stddev_in_range
            )
        if profile_population_stddev_in_range is not UNSET:
            field_dict["profile_population_stddev_in_range"] = (
                profile_population_stddev_in_range
            )
        if profile_sample_variance_in_range is not UNSET:
            field_dict["profile_sample_variance_in_range"] = (
                profile_sample_variance_in_range
            )
        if profile_population_variance_in_range is not UNSET:
            field_dict["profile_population_variance_in_range"] = (
                profile_population_variance_in_range
            )
        if profile_invalid_latitude is not UNSET:
            field_dict["profile_invalid_latitude"] = profile_invalid_latitude
        if profile_valid_latitude_percent is not UNSET:
            field_dict["profile_valid_latitude_percent"] = (
                profile_valid_latitude_percent
            )
        if profile_invalid_longitude is not UNSET:
            field_dict["profile_invalid_longitude"] = profile_invalid_longitude
        if profile_valid_longitude_percent is not UNSET:
            field_dict["profile_valid_longitude_percent"] = (
                profile_valid_longitude_percent
            )
        if profile_non_negative_values is not UNSET:
            field_dict["profile_non_negative_values"] = profile_non_negative_values
        if profile_non_negative_values_percent is not UNSET:
            field_dict["profile_non_negative_values_percent"] = (
                profile_non_negative_values_percent
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_integer_in_range_percent_check_spec import (
            ColumnIntegerInRangePercentCheckSpec,
        )
        from ..models.column_invalid_latitude_count_check_spec import (
            ColumnInvalidLatitudeCountCheckSpec,
        )
        from ..models.column_invalid_longitude_count_check_spec import (
            ColumnInvalidLongitudeCountCheckSpec,
        )
        from ..models.column_max_in_range_check_spec import ColumnMaxInRangeCheckSpec
        from ..models.column_mean_in_range_check_spec import ColumnMeanInRangeCheckSpec
        from ..models.column_median_in_range_check_spec import (
            ColumnMedianInRangeCheckSpec,
        )
        from ..models.column_min_in_range_check_spec import ColumnMinInRangeCheckSpec
        from ..models.column_negative_count_check_spec import (
            ColumnNegativeCountCheckSpec,
        )
        from ..models.column_negative_percent_check_spec import (
            ColumnNegativePercentCheckSpec,
        )
        from ..models.column_non_negative_count_check_spec import (
            ColumnNonNegativeCountCheckSpec,
        )
        from ..models.column_non_negative_percent_check_spec import (
            ColumnNonNegativePercentCheckSpec,
        )
        from ..models.column_number_above_max_value_check_spec import (
            ColumnNumberAboveMaxValueCheckSpec,
        )
        from ..models.column_number_above_max_value_percent_check_spec import (
            ColumnNumberAboveMaxValuePercentCheckSpec,
        )
        from ..models.column_number_below_min_value_check_spec import (
            ColumnNumberBelowMinValueCheckSpec,
        )
        from ..models.column_number_below_min_value_percent_check_spec import (
            ColumnNumberBelowMinValuePercentCheckSpec,
        )
        from ..models.column_number_in_range_percent_check_spec import (
            ColumnNumberInRangePercentCheckSpec,
        )
        from ..models.column_numeric_profiling_checks_spec_custom_checks import (
            ColumnNumericProfilingChecksSpecCustomChecks,
        )
        from ..models.column_percentile_10_in_range_check_spec import (
            ColumnPercentile10InRangeCheckSpec,
        )
        from ..models.column_percentile_25_in_range_check_spec import (
            ColumnPercentile25InRangeCheckSpec,
        )
        from ..models.column_percentile_75_in_range_check_spec import (
            ColumnPercentile75InRangeCheckSpec,
        )
        from ..models.column_percentile_90_in_range_check_spec import (
            ColumnPercentile90InRangeCheckSpec,
        )
        from ..models.column_percentile_in_range_check_spec import (
            ColumnPercentileInRangeCheckSpec,
        )
        from ..models.column_population_stddev_in_range_check_spec import (
            ColumnPopulationStddevInRangeCheckSpec,
        )
        from ..models.column_population_variance_in_range_check_spec import (
            ColumnPopulationVarianceInRangeCheckSpec,
        )
        from ..models.column_sample_stddev_in_range_check_spec import (
            ColumnSampleStddevInRangeCheckSpec,
        )
        from ..models.column_sample_variance_in_range_check_spec import (
            ColumnSampleVarianceInRangeCheckSpec,
        )
        from ..models.column_sum_in_range_check_spec import ColumnSumInRangeCheckSpec
        from ..models.column_valid_latitude_percent_check_spec import (
            ColumnValidLatitudePercentCheckSpec,
        )
        from ..models.column_valid_longitude_percent_check_spec import (
            ColumnValidLongitudePercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, ColumnNumericProfilingChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = ColumnNumericProfilingChecksSpecCustomChecks.from_dict(
                _custom_checks
            )

        _profile_number_below_min_value = d.pop("profile_number_below_min_value", UNSET)
        profile_number_below_min_value: Union[Unset, ColumnNumberBelowMinValueCheckSpec]
        if isinstance(_profile_number_below_min_value, Unset):
            profile_number_below_min_value = UNSET
        else:
            profile_number_below_min_value = (
                ColumnNumberBelowMinValueCheckSpec.from_dict(
                    _profile_number_below_min_value
                )
            )

        _profile_number_above_max_value = d.pop("profile_number_above_max_value", UNSET)
        profile_number_above_max_value: Union[Unset, ColumnNumberAboveMaxValueCheckSpec]
        if isinstance(_profile_number_above_max_value, Unset):
            profile_number_above_max_value = UNSET
        else:
            profile_number_above_max_value = (
                ColumnNumberAboveMaxValueCheckSpec.from_dict(
                    _profile_number_above_max_value
                )
            )

        _profile_negative_values = d.pop("profile_negative_values", UNSET)
        profile_negative_values: Union[Unset, ColumnNegativeCountCheckSpec]
        if isinstance(_profile_negative_values, Unset):
            profile_negative_values = UNSET
        else:
            profile_negative_values = ColumnNegativeCountCheckSpec.from_dict(
                _profile_negative_values
            )

        _profile_negative_values_percent = d.pop(
            "profile_negative_values_percent", UNSET
        )
        profile_negative_values_percent: Union[Unset, ColumnNegativePercentCheckSpec]
        if isinstance(_profile_negative_values_percent, Unset):
            profile_negative_values_percent = UNSET
        else:
            profile_negative_values_percent = ColumnNegativePercentCheckSpec.from_dict(
                _profile_negative_values_percent
            )

        _profile_number_below_min_value_percent = d.pop(
            "profile_number_below_min_value_percent", UNSET
        )
        profile_number_below_min_value_percent: Union[
            Unset, ColumnNumberBelowMinValuePercentCheckSpec
        ]
        if isinstance(_profile_number_below_min_value_percent, Unset):
            profile_number_below_min_value_percent = UNSET
        else:
            profile_number_below_min_value_percent = (
                ColumnNumberBelowMinValuePercentCheckSpec.from_dict(
                    _profile_number_below_min_value_percent
                )
            )

        _profile_number_above_max_value_percent = d.pop(
            "profile_number_above_max_value_percent", UNSET
        )
        profile_number_above_max_value_percent: Union[
            Unset, ColumnNumberAboveMaxValuePercentCheckSpec
        ]
        if isinstance(_profile_number_above_max_value_percent, Unset):
            profile_number_above_max_value_percent = UNSET
        else:
            profile_number_above_max_value_percent = (
                ColumnNumberAboveMaxValuePercentCheckSpec.from_dict(
                    _profile_number_above_max_value_percent
                )
            )

        _profile_number_in_range_percent = d.pop(
            "profile_number_in_range_percent", UNSET
        )
        profile_number_in_range_percent: Union[
            Unset, ColumnNumberInRangePercentCheckSpec
        ]
        if isinstance(_profile_number_in_range_percent, Unset):
            profile_number_in_range_percent = UNSET
        else:
            profile_number_in_range_percent = (
                ColumnNumberInRangePercentCheckSpec.from_dict(
                    _profile_number_in_range_percent
                )
            )

        _profile_integer_in_range_percent = d.pop(
            "profile_integer_in_range_percent", UNSET
        )
        profile_integer_in_range_percent: Union[
            Unset, ColumnIntegerInRangePercentCheckSpec
        ]
        if isinstance(_profile_integer_in_range_percent, Unset):
            profile_integer_in_range_percent = UNSET
        else:
            profile_integer_in_range_percent = (
                ColumnIntegerInRangePercentCheckSpec.from_dict(
                    _profile_integer_in_range_percent
                )
            )

        _profile_min_in_range = d.pop("profile_min_in_range", UNSET)
        profile_min_in_range: Union[Unset, ColumnMinInRangeCheckSpec]
        if isinstance(_profile_min_in_range, Unset):
            profile_min_in_range = UNSET
        else:
            profile_min_in_range = ColumnMinInRangeCheckSpec.from_dict(
                _profile_min_in_range
            )

        _profile_max_in_range = d.pop("profile_max_in_range", UNSET)
        profile_max_in_range: Union[Unset, ColumnMaxInRangeCheckSpec]
        if isinstance(_profile_max_in_range, Unset):
            profile_max_in_range = UNSET
        else:
            profile_max_in_range = ColumnMaxInRangeCheckSpec.from_dict(
                _profile_max_in_range
            )

        _profile_sum_in_range = d.pop("profile_sum_in_range", UNSET)
        profile_sum_in_range: Union[Unset, ColumnSumInRangeCheckSpec]
        if isinstance(_profile_sum_in_range, Unset):
            profile_sum_in_range = UNSET
        else:
            profile_sum_in_range = ColumnSumInRangeCheckSpec.from_dict(
                _profile_sum_in_range
            )

        _profile_mean_in_range = d.pop("profile_mean_in_range", UNSET)
        profile_mean_in_range: Union[Unset, ColumnMeanInRangeCheckSpec]
        if isinstance(_profile_mean_in_range, Unset):
            profile_mean_in_range = UNSET
        else:
            profile_mean_in_range = ColumnMeanInRangeCheckSpec.from_dict(
                _profile_mean_in_range
            )

        _profile_median_in_range = d.pop("profile_median_in_range", UNSET)
        profile_median_in_range: Union[Unset, ColumnMedianInRangeCheckSpec]
        if isinstance(_profile_median_in_range, Unset):
            profile_median_in_range = UNSET
        else:
            profile_median_in_range = ColumnMedianInRangeCheckSpec.from_dict(
                _profile_median_in_range
            )

        _profile_percentile_in_range = d.pop("profile_percentile_in_range", UNSET)
        profile_percentile_in_range: Union[Unset, ColumnPercentileInRangeCheckSpec]
        if isinstance(_profile_percentile_in_range, Unset):
            profile_percentile_in_range = UNSET
        else:
            profile_percentile_in_range = ColumnPercentileInRangeCheckSpec.from_dict(
                _profile_percentile_in_range
            )

        _profile_percentile_10_in_range = d.pop("profile_percentile_10_in_range", UNSET)
        profile_percentile_10_in_range: Union[Unset, ColumnPercentile10InRangeCheckSpec]
        if isinstance(_profile_percentile_10_in_range, Unset):
            profile_percentile_10_in_range = UNSET
        else:
            profile_percentile_10_in_range = (
                ColumnPercentile10InRangeCheckSpec.from_dict(
                    _profile_percentile_10_in_range
                )
            )

        _profile_percentile_25_in_range = d.pop("profile_percentile_25_in_range", UNSET)
        profile_percentile_25_in_range: Union[Unset, ColumnPercentile25InRangeCheckSpec]
        if isinstance(_profile_percentile_25_in_range, Unset):
            profile_percentile_25_in_range = UNSET
        else:
            profile_percentile_25_in_range = (
                ColumnPercentile25InRangeCheckSpec.from_dict(
                    _profile_percentile_25_in_range
                )
            )

        _profile_percentile_75_in_range = d.pop("profile_percentile_75_in_range", UNSET)
        profile_percentile_75_in_range: Union[Unset, ColumnPercentile75InRangeCheckSpec]
        if isinstance(_profile_percentile_75_in_range, Unset):
            profile_percentile_75_in_range = UNSET
        else:
            profile_percentile_75_in_range = (
                ColumnPercentile75InRangeCheckSpec.from_dict(
                    _profile_percentile_75_in_range
                )
            )

        _profile_percentile_90_in_range = d.pop("profile_percentile_90_in_range", UNSET)
        profile_percentile_90_in_range: Union[Unset, ColumnPercentile90InRangeCheckSpec]
        if isinstance(_profile_percentile_90_in_range, Unset):
            profile_percentile_90_in_range = UNSET
        else:
            profile_percentile_90_in_range = (
                ColumnPercentile90InRangeCheckSpec.from_dict(
                    _profile_percentile_90_in_range
                )
            )

        _profile_sample_stddev_in_range = d.pop("profile_sample_stddev_in_range", UNSET)
        profile_sample_stddev_in_range: Union[Unset, ColumnSampleStddevInRangeCheckSpec]
        if isinstance(_profile_sample_stddev_in_range, Unset):
            profile_sample_stddev_in_range = UNSET
        else:
            profile_sample_stddev_in_range = (
                ColumnSampleStddevInRangeCheckSpec.from_dict(
                    _profile_sample_stddev_in_range
                )
            )

        _profile_population_stddev_in_range = d.pop(
            "profile_population_stddev_in_range", UNSET
        )
        profile_population_stddev_in_range: Union[
            Unset, ColumnPopulationStddevInRangeCheckSpec
        ]
        if isinstance(_profile_population_stddev_in_range, Unset):
            profile_population_stddev_in_range = UNSET
        else:
            profile_population_stddev_in_range = (
                ColumnPopulationStddevInRangeCheckSpec.from_dict(
                    _profile_population_stddev_in_range
                )
            )

        _profile_sample_variance_in_range = d.pop(
            "profile_sample_variance_in_range", UNSET
        )
        profile_sample_variance_in_range: Union[
            Unset, ColumnSampleVarianceInRangeCheckSpec
        ]
        if isinstance(_profile_sample_variance_in_range, Unset):
            profile_sample_variance_in_range = UNSET
        else:
            profile_sample_variance_in_range = (
                ColumnSampleVarianceInRangeCheckSpec.from_dict(
                    _profile_sample_variance_in_range
                )
            )

        _profile_population_variance_in_range = d.pop(
            "profile_population_variance_in_range", UNSET
        )
        profile_population_variance_in_range: Union[
            Unset, ColumnPopulationVarianceInRangeCheckSpec
        ]
        if isinstance(_profile_population_variance_in_range, Unset):
            profile_population_variance_in_range = UNSET
        else:
            profile_population_variance_in_range = (
                ColumnPopulationVarianceInRangeCheckSpec.from_dict(
                    _profile_population_variance_in_range
                )
            )

        _profile_invalid_latitude = d.pop("profile_invalid_latitude", UNSET)
        profile_invalid_latitude: Union[Unset, ColumnInvalidLatitudeCountCheckSpec]
        if isinstance(_profile_invalid_latitude, Unset):
            profile_invalid_latitude = UNSET
        else:
            profile_invalid_latitude = ColumnInvalidLatitudeCountCheckSpec.from_dict(
                _profile_invalid_latitude
            )

        _profile_valid_latitude_percent = d.pop("profile_valid_latitude_percent", UNSET)
        profile_valid_latitude_percent: Union[
            Unset, ColumnValidLatitudePercentCheckSpec
        ]
        if isinstance(_profile_valid_latitude_percent, Unset):
            profile_valid_latitude_percent = UNSET
        else:
            profile_valid_latitude_percent = (
                ColumnValidLatitudePercentCheckSpec.from_dict(
                    _profile_valid_latitude_percent
                )
            )

        _profile_invalid_longitude = d.pop("profile_invalid_longitude", UNSET)
        profile_invalid_longitude: Union[Unset, ColumnInvalidLongitudeCountCheckSpec]
        if isinstance(_profile_invalid_longitude, Unset):
            profile_invalid_longitude = UNSET
        else:
            profile_invalid_longitude = ColumnInvalidLongitudeCountCheckSpec.from_dict(
                _profile_invalid_longitude
            )

        _profile_valid_longitude_percent = d.pop(
            "profile_valid_longitude_percent", UNSET
        )
        profile_valid_longitude_percent: Union[
            Unset, ColumnValidLongitudePercentCheckSpec
        ]
        if isinstance(_profile_valid_longitude_percent, Unset):
            profile_valid_longitude_percent = UNSET
        else:
            profile_valid_longitude_percent = (
                ColumnValidLongitudePercentCheckSpec.from_dict(
                    _profile_valid_longitude_percent
                )
            )

        _profile_non_negative_values = d.pop("profile_non_negative_values", UNSET)
        profile_non_negative_values: Union[Unset, ColumnNonNegativeCountCheckSpec]
        if isinstance(_profile_non_negative_values, Unset):
            profile_non_negative_values = UNSET
        else:
            profile_non_negative_values = ColumnNonNegativeCountCheckSpec.from_dict(
                _profile_non_negative_values
            )

        _profile_non_negative_values_percent = d.pop(
            "profile_non_negative_values_percent", UNSET
        )
        profile_non_negative_values_percent: Union[
            Unset, ColumnNonNegativePercentCheckSpec
        ]
        if isinstance(_profile_non_negative_values_percent, Unset):
            profile_non_negative_values_percent = UNSET
        else:
            profile_non_negative_values_percent = (
                ColumnNonNegativePercentCheckSpec.from_dict(
                    _profile_non_negative_values_percent
                )
            )

        column_numeric_profiling_checks_spec = cls(
            custom_checks=custom_checks,
            profile_number_below_min_value=profile_number_below_min_value,
            profile_number_above_max_value=profile_number_above_max_value,
            profile_negative_values=profile_negative_values,
            profile_negative_values_percent=profile_negative_values_percent,
            profile_number_below_min_value_percent=profile_number_below_min_value_percent,
            profile_number_above_max_value_percent=profile_number_above_max_value_percent,
            profile_number_in_range_percent=profile_number_in_range_percent,
            profile_integer_in_range_percent=profile_integer_in_range_percent,
            profile_min_in_range=profile_min_in_range,
            profile_max_in_range=profile_max_in_range,
            profile_sum_in_range=profile_sum_in_range,
            profile_mean_in_range=profile_mean_in_range,
            profile_median_in_range=profile_median_in_range,
            profile_percentile_in_range=profile_percentile_in_range,
            profile_percentile_10_in_range=profile_percentile_10_in_range,
            profile_percentile_25_in_range=profile_percentile_25_in_range,
            profile_percentile_75_in_range=profile_percentile_75_in_range,
            profile_percentile_90_in_range=profile_percentile_90_in_range,
            profile_sample_stddev_in_range=profile_sample_stddev_in_range,
            profile_population_stddev_in_range=profile_population_stddev_in_range,
            profile_sample_variance_in_range=profile_sample_variance_in_range,
            profile_population_variance_in_range=profile_population_variance_in_range,
            profile_invalid_latitude=profile_invalid_latitude,
            profile_valid_latitude_percent=profile_valid_latitude_percent,
            profile_invalid_longitude=profile_invalid_longitude,
            profile_valid_longitude_percent=profile_valid_longitude_percent,
            profile_non_negative_values=profile_non_negative_values,
            profile_non_negative_values_percent=profile_non_negative_values_percent,
        )

        column_numeric_profiling_checks_spec.additional_properties = d
        return column_numeric_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class BigQueryJobsCreateProject(str, Enum):
    CREATE_JOBS_IN_DEFAULT_PROJECT_FROM_CREDENTIALS = (
        "create_jobs_in_default_project_from_credentials"
    )
    CREATE_JOBS_IN_SELECTED_BILLING_PROJECT_ID = (
        "create_jobs_in_selected_billing_project_id"
    )
    CREATE_JOBS_IN_SOURCE_PROJECT = "create_jobs_in_source_project"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="CheckDefinitionListModel")


@_attrs_define
class CheckDefinitionListModel:
    """Data quality check definition list model.

    Attributes:
        check_name (Union[Unset, str]): Check name
        full_check_name (Union[Unset, str]): Full check name
        custom (Union[Unset, bool]): This check has is a custom check or was customized by the user.
        built_in (Union[Unset, bool]): This check is provided with DQOps as a built-in check.
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
        yaml_parsing_error (Union[Unset, str]): Optional parsing error that was captured when parsing the YAML file.
            This field is null when the YAML file is valid. If an error was captured, this field returns the file parsing
            error message and the file location.
    """

    check_name: Union[Unset, str] = UNSET
    full_check_name: Union[Unset, str] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    yaml_parsing_error: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_name = self.check_name
        full_check_name = self.full_check_name
        custom = self.custom
        built_in = self.built_in
        can_edit = self.can_edit
        yaml_parsing_error = self.yaml_parsing_error

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_name is not UNSET:
            field_dict["check_name"] = check_name
        if full_check_name is not UNSET:
            field_dict["full_check_name"] = full_check_name
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["built_in"] = built_in
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if yaml_parsing_error is not UNSET:
            field_dict["yaml_parsing_error"] = yaml_parsing_error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        check_name = d.pop("check_name", UNSET)

        full_check_name = d.pop("full_check_name", UNSET)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("built_in", UNSET)

        can_edit = d.pop("can_edit", UNSET)

        yaml_parsing_error = d.pop("yaml_parsing_error", UNSET)

        check_definition_list_model = cls(
            check_name=check_name,
            full_check_name=full_check_name,
            custom=custom,
            built_in=built_in,
            can_edit=can_edit,
            yaml_parsing_error=yaml_parsing_error,
        )

        check_definition_list_model.additional_properties = d
        return check_definition_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_spec import TableSpec


T = TypeVar("T", bound="ImportTablesResult")


@_attrs_define
class ImportTablesResult:
    """Result object returned from the "import tables" job. Contains the original table schemas and column schemas of
    imported tables.

        Attributes:
            source_table_specs (Union[Unset, List['TableSpec']]): Table schemas (including column schemas) of imported
                tables.
    """

    source_table_specs: Union[Unset, List["TableSpec"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        source_table_specs: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.source_table_specs, Unset):
            source_table_specs = []
            for source_table_specs_item_data in self.source_table_specs:
                source_table_specs_item = source_table_specs_item_data.to_dict()

                source_table_specs.append(source_table_specs_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if source_table_specs is not UNSET:
            field_dict["source_table_specs"] = source_table_specs

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_spec import TableSpec

        d = src_dict.copy()
        source_table_specs = []
        _source_table_specs = d.pop("source_table_specs", UNSET)
        for source_table_specs_item_data in _source_table_specs or []:
            source_table_specs_item = TableSpec.from_dict(source_table_specs_item_data)

            source_table_specs.append(source_table_specs_item)

        import_tables_result = cls(
            source_table_specs=source_table_specs,
        )

        import_tables_result.additional_properties = d
        return import_tables_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class StatisticsResultDataType(str, Enum):
    BOOLEAN = "boolean"
    DATE = "date"
    DATETIME = "datetime"
    FLOAT = "float"
    INSTANT = "instant"
    INTEGER = "integer"
    NULL = "null"
    STRING = "string"
    TIME = "time"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="TimeWindowFilterParameters")


@_attrs_define
class TimeWindowFilterParameters:
    """Time window configuration for partitioned checks (the number of recent days or months to analyze in an incremental
    mode) or an absolute time range to analyze.

        Attributes:
            daily_partitioning_recent_days (Union[Unset, int]): The number of recent days to analyze incrementally by daily
                partitioned data quality checks.
            daily_partitioning_include_today (Union[Unset, bool]): Analyze also today and later days when running daily
                partitioned checks. By default, daily partitioned checks will not analyze today and future dates. Setting true
                will disable filtering the end dates.
            monthly_partitioning_recent_months (Union[Unset, int]): The number of recent months to analyze incrementally by
                monthly partitioned data quality checks.
            monthly_partitioning_include_current_month (Union[Unset, bool]): Analyze also the current month and later months
                when running monthly partitioned checks. By default, monthly partitioned checks will not analyze the current
                month and future months. Setting true will disable filtering the end dates.
            from_date (Union[Unset, datetime.date]): Analyze the data since the given date (inclusive). The date should be
                an ISO 8601 date (yyyy-MM-dd). The analyzed table must have the timestamp column properly configured, it is the
                column that is used for filtering the date and time ranges. Setting the beginning date overrides recent days and
                recent months.
            from_date_time (Union[Unset, datetime.datetime]): Analyze the data since the given date and time (inclusive).
                The date and time should be an ISO 8601 local date and time without the time zone (yyyy-MM-dd HH:mm:ss). The
                analyzed table must have the timestamp column properly configured, it is the column that is used for filtering
                the date and time ranges. Setting the beginning date and time overrides recent days and recent months.
            from_date_time_offset (Union[Unset, datetime.datetime]): Analyze the data since the given date and time with a
                time zone offset (inclusive). The date and time should be an ISO 8601 date and time followed by a time zone
                offset (yyyy-MM-dd HH:mm:ss). For example: 2023-02-20 14:10:00+02. The analyzed table must have the timestamp
                column properly configured, it is the column that is used for filtering the date and time ranges. Setting the
                beginning date and time overrides recent days and recent months.
            to_date (Union[Unset, datetime.date]): Analyze the data until the given date (exclusive, the given date and the
                following dates are not analyzed). The date should be an ISO 8601 date (YYYY-MM-DD). The analyzed table must
                have the timestamp column properly configured, it is the column that is used for filtering the date and time
                ranges. Setting the end date overrides the parameters to disable analyzing today or the current month.
            to_date_time (Union[Unset, datetime.datetime]): Analyze the data until the given date and time (exclusive). The
                date should be an ISO 8601 date (yyyy-MM-dd). The analyzed table must have the timestamp column properly
                configured, it is the column that is used for filtering the date and time ranges. Setting the end date and time
                overrides the parameters to disable analyzing today or the current month.
            to_date_time_offset (Union[Unset, datetime.datetime]): Analyze the data until the given date and time with a
                time zone offset (exclusive). The date and time should be an ISO 8601 date and time followed by a time zone
                offset (yyyy-MM-dd HH:mm:ss). For example: 2023-02-20 14:10:00+02. The analyzed table must have the timestamp
                column properly configured, it is the column that is used for filtering the date and time ranges. Setting the
                end date and time overrides the parameters to disable analyzing today or the current month.
            where_filter (Union[Unset, str]): An additional filter which must be a valid SQL predicate (an SQL expression
                that returns 'true' or 'false') that is added to the WHERE clause of the SQL query that DQOps will run on the
                data source. The purpose of a custom filter is to analyze only a subset of data, for example, when a new batch
                of records is loaded, and the data quality checks are evaluated as a data contract. All the records in that
                batch must tagged with the same value, and the passed predicate to find records from that batch would use the
                filter in the form: "{alias}.batch_id = 1". The filter can use replacement tokens {alias} to reference the
                analyzed table.
    """

    daily_partitioning_recent_days: Union[Unset, int] = UNSET
    daily_partitioning_include_today: Union[Unset, bool] = UNSET
    monthly_partitioning_recent_months: Union[Unset, int] = UNSET
    monthly_partitioning_include_current_month: Union[Unset, bool] = UNSET
    from_date: Union[Unset, datetime.date] = UNSET
    from_date_time: Union[Unset, datetime.datetime] = UNSET
    from_date_time_offset: Union[Unset, datetime.datetime] = UNSET
    to_date: Union[Unset, datetime.date] = UNSET
    to_date_time: Union[Unset, datetime.datetime] = UNSET
    to_date_time_offset: Union[Unset, datetime.datetime] = UNSET
    where_filter: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        daily_partitioning_recent_days = self.daily_partitioning_recent_days
        daily_partitioning_include_today = self.daily_partitioning_include_today
        monthly_partitioning_recent_months = self.monthly_partitioning_recent_months
        monthly_partitioning_include_current_month = (
            self.monthly_partitioning_include_current_month
        )
        from_date: Union[Unset, str] = UNSET
        if not isinstance(self.from_date, Unset):
            from_date = self.from_date.isoformat()

        from_date_time: Union[Unset, str] = UNSET
        if not isinstance(self.from_date_time, Unset):
            from_date_time = self.from_date_time.isoformat()

        from_date_time_offset: Union[Unset, str] = UNSET
        if not isinstance(self.from_date_time_offset, Unset):
            from_date_time_offset = self.from_date_time_offset.isoformat()

        to_date: Union[Unset, str] = UNSET
        if not isinstance(self.to_date, Unset):
            to_date = self.to_date.isoformat()

        to_date_time: Union[Unset, str] = UNSET
        if not isinstance(self.to_date_time, Unset):
            to_date_time = self.to_date_time.isoformat()

        to_date_time_offset: Union[Unset, str] = UNSET
        if not isinstance(self.to_date_time_offset, Unset):
            to_date_time_offset = self.to_date_time_offset.isoformat()

        where_filter = self.where_filter

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if daily_partitioning_recent_days is not UNSET:
            field_dict["daily_partitioning_recent_days"] = (
                daily_partitioning_recent_days
            )
        if daily_partitioning_include_today is not UNSET:
            field_dict["daily_partitioning_include_today"] = (
                daily_partitioning_include_today
            )
        if monthly_partitioning_recent_months is not UNSET:
            field_dict["monthly_partitioning_recent_months"] = (
                monthly_partitioning_recent_months
            )
        if monthly_partitioning_include_current_month is not UNSET:
            field_dict["monthly_partitioning_include_current_month"] = (
                monthly_partitioning_include_current_month
            )
        if from_date is not UNSET:
            field_dict["from_date"] = from_date
        if from_date_time is not UNSET:
            field_dict["from_date_time"] = from_date_time
        if from_date_time_offset is not UNSET:
            field_dict["from_date_time_offset"] = from_date_time_offset
        if to_date is not UNSET:
            field_dict["to_date"] = to_date
        if to_date_time is not UNSET:
            field_dict["to_date_time"] = to_date_time
        if to_date_time_offset is not UNSET:
            field_dict["to_date_time_offset"] = to_date_time_offset
        if where_filter is not UNSET:
            field_dict["where_filter"] = where_filter

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        daily_partitioning_recent_days = d.pop("daily_partitioning_recent_days", UNSET)

        daily_partitioning_include_today = d.pop(
            "daily_partitioning_include_today", UNSET
        )

        monthly_partitioning_recent_months = d.pop(
            "monthly_partitioning_recent_months", UNSET
        )

        monthly_partitioning_include_current_month = d.pop(
            "monthly_partitioning_include_current_month", UNSET
        )

        _from_date = d.pop("from_date", UNSET)
        from_date: Union[Unset, datetime.date]
        if isinstance(_from_date, Unset):
            from_date = UNSET
        else:
            from_date = isoparse(_from_date).date()

        _from_date_time = d.pop("from_date_time", UNSET)
        from_date_time: Union[Unset, datetime.datetime]
        if isinstance(_from_date_time, Unset):
            from_date_time = UNSET
        else:
            from_date_time = isoparse(_from_date_time)

        _from_date_time_offset = d.pop("from_date_time_offset", UNSET)
        from_date_time_offset: Union[Unset, datetime.datetime]
        if isinstance(_from_date_time_offset, Unset):
            from_date_time_offset = UNSET
        else:
            from_date_time_offset = isoparse(_from_date_time_offset)

        _to_date = d.pop("to_date", UNSET)
        to_date: Union[Unset, datetime.date]
        if isinstance(_to_date, Unset):
            to_date = UNSET
        else:
            to_date = isoparse(_to_date).date()

        _to_date_time = d.pop("to_date_time", UNSET)
        to_date_time: Union[Unset, datetime.datetime]
        if isinstance(_to_date_time, Unset):
            to_date_time = UNSET
        else:
            to_date_time = isoparse(_to_date_time)

        _to_date_time_offset = d.pop("to_date_time_offset", UNSET)
        to_date_time_offset: Union[Unset, datetime.datetime]
        if isinstance(_to_date_time_offset, Unset):
            to_date_time_offset = UNSET
        else:
            to_date_time_offset = isoparse(_to_date_time_offset)

        where_filter = d.pop("where_filter", UNSET)

        time_window_filter_parameters = cls(
            daily_partitioning_recent_days=daily_partitioning_recent_days,
            daily_partitioning_include_today=daily_partitioning_include_today,
            monthly_partitioning_recent_months=monthly_partitioning_recent_months,
            monthly_partitioning_include_current_month=monthly_partitioning_include_current_month,
            from_date=from_date,
            from_date_time=from_date_time,
            from_date_time_offset=from_date_time_offset,
            to_date=to_date,
            to_date_time=to_date_time,
            to_date_time_offset=to_date_time_offset,
            where_filter=where_filter,
        )

        time_window_filter_parameters.additional_properties = d
        return time_window_filter_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
